/*##TEXT-DATEI
;-------------------------------------------------------------------------------
;##Copyright        :  Hartmann & Braun AG
;
;-------------------------------------------------------------------------------
;##System           :  CONTRANS T
;##Systemkomponente :  Temperaturmessumformer TH02
;                      (Transmitter spez. Dokument: Rev. 1)
;-------------------------------------------------------------------------------
;##Programm         :  HC-DDL
;##Modul            :  -/-
;##Pfad/Datei       :  THXXX.DCT
;##Library/Overlay  :  -/-
;##Programmierer    :  K.Pose / PLC-Alz
;##Erst.-Datum      :  02.03.2000
;##Version/Datum    :  01.00 / 02.03.2000
;-------------------------------------------------------------------------------
;##Beschreibung     :  Zentrale Textdatei fuer die Geraetebeschreibung der
;                      Messumformer THXXX.
;
;                      Damit die Datei korrekt in eine Geraetebeschreibung
;                      eingebunden werden kann, muss vor der #include-
;                      Anweisung fuer diese Datei die folgende Direktive
;                      ausgefhrt werden:
;
;                      1. TH02:      #define __TH02__
;
;##SPECEND
;-------------------------------------------------------------------------------
;###*/

#ifndef __THXXX_DCT__
#define __THXXX_DCT__


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/*                                                                            */
/*  AUFBAU DER TEXTDATEI:                                                     */
/*                                                                            */
/*  - Allgemeines:                                                            */
/*                                                                            */
/*    Das HHT275 erwartet den ISO Latin1-Zeichensatz. Um falsche              */
/*    Darstellungen zu vermeiden, sollte ein WINDOWS-Editor (nicht mit        */
/*    Zeichensatz TERMINAL) verwendet werden, wenn Sonderzeichen wie Umlaute  */
/*    eingesetzt werden.                                                      */
/*                                                                            */
/*    Der nutzbare Anzeigeumfang des HHT275 umfasst 8 Zeilen  20 Zeichen.    */
/*    Je nach Funktion findet ein automatischer Zeilenumbruch statt oder die  */
/*    Zeilen werden bei Ueberlaenge gekappt.                                  */
/*                                                                            */
/*    Daraus folgt als erste Forderung:                                       */
/*                                                                            */
/*                KEIN WORT DARF LAENGER ALS 20 ZEICHEN SEIN !!!              */
/*                                                                            */
/*    Zeilenumbrueche in dieser Datei werden nicht in die HHT-Darstellung     */
/*    uebernommen. Ein zwingender Zeilenumbruch im HHT wird durch die         */
/*    Sequenz '\n' erreicht.                                                  */
/*                                                                            */
/*    Wenn auf eine Textzeile weitere Fortsetzungszeilen folgen, MUSS die     */
/*    Zeile mit einem '\' abgeschlossen werden.                               */
/*                                                                            */
/*    Die Texte werden im Programm durch ein Referenzwort (hinter '#define')  */
/*    aufgerufen. Diese Begriffe duerfen auf keinen Fall geaendert werden.    */
/*                                                                            */
/*    Weitere Beschraenkungen haengen von der Verwendung der Texte ab.        */
/*                                                                            */
/*                                                                            */
/*  - 'Normale' Texte:                                                        */
/*                                                                            */
/*    Normale Texte sind fuer Hinweise oder Eingaben gedacht. Sie sind wie    */
/*    folgt aufgebaut:                                                        */
/*                                                                            */
/*    #define TXT_...      "|en|<englischer Text>"\                           */
/*                         "|de|<deutscher Text>"                             */
/*                                                                            */
/*    Diese Texte koennen je nach Verwendung nur einzeilig oder einseitig     */
/*    dargestellt werden. 'Blaettern' ist in jedem Fall nicht moeglich.       */
/*                                                                            */
/*    ACHTUNG:  Weil durch den Zeilenumbruch nicht alle Zeilen bis zum Ende   */
/*              ausgenutzt werden koennen, sind auch bei mehrzeiliger Dar-    */
/*              stellung nicht 20*8 Textzeichen moeglich!                     */
/*                                                                            */
/*    Bei Texten, die nur einzeilig darstellbar sind, wird die max.           */
/*    zulaessige Anzahl der Zeichen in der Zeile oberhalb des Referenz-       */
/*    wortes angegeben. Die Beschraenkung gilt dann fuer alle Texte bis zur   */
/*    naechsten Leerzeile.                                                    */
/*                                                                            */
/*  - Texte mit Variablen:                                                    */
/*    #define VXT_...                                                         */
/*                                                                            */
/*  - Hilfetexte:                                                             */
/*                                                                            */
/*    Hilfetexte sollen weiterfuehrende Angaben enthalten. Sie sind an ihrem  */
/*    Referenzwort zu erkennen:                                               */
/*                                                                            */
/*    #define HLP_...      "|en|<englischer Text>"\                           */
/*                         "|de|<deutscher Text>"                             */
/*                                                                            */
/*    Hier wird immer ein automatischer Zeilenumbruch durchgefuehrt.          */
/*    Ausserdem kann im Text geblaettert werden. Daher sind in den Hilfetext  */
/*    keine weiteren Einschraenkungen zu beachten.                            */
/*                                                                            */
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */



/*
 *  THxxxME.DDL
 */

#define TXT_UPLOAD_VARS        "|en|write_variables"\
                               "|de|Offline-Parameter"

#define TXT_TRIMPRESET_SERVICES    "|en|Trimmings / Preset"\
                                   "|de|Abgleich / Preset"

/*
 *  THxxxR1.DDL
 */

/* max. 20 Zeichen */
#define TXT_PRIMARY_MEASURE    "|en|Measured value"\
                               "|de|Mewert"
#define TXT_SECONDARY_MEASURE  "|en|Ref. junction temp."\
                               "|de|Vergl.-stellentemp."
#define TXT_DYNAMIC_VARIABLES  "|en|Dynamic variables"\
                               "|de|Dynamische Variablen"


#ifdef __TH02__

#define HLP_PRIMARY_MEASURE    "|en|Measured value - The calculated measured "\
                                   "value acquired through parameterised "\
                                   "processing, during multi-channel "\
                                   "measurements of both channels. Output is "\
                                   "made in the set process unit."\
                               "|de|Mewert - Der durch die parametrierte "\
                                   "Verarbeitung errechnete Mewert, bei "\
                                   "mehrkanaligen Messungen als Kombination "\
                                   "beider Kanle. Die Ausgabe erfolgt in der "\
                                   "eingestellten Prozeeinheit."


#endif /* __TH02__ */


#define HLP_SECONDARY_MEASURE  "|en|Reference junction temp. - The value is "\
                                   "required for correction during "\
                                   "measurements with thermocouples. "\
                                   "The measured value produces the "\
                                   "temperature at the terminal block of the "\
                                   "field unit."\
                               "|de|Vergl.-stellentemp. - Der Wert wird zur "\
                                   "Korrektur bei Messungen mit "\
                                   "Thermoelementen bentigt. Der Mewert "\
                                   "gibt die Temperatur am Klemmenblock des "\
                                   "Feldgertes an."

/* max. 20 Zeichen */
#define TXT_AO_ALARM_CODE      "|en|Alarm type"\
                               "|de|Alarm-Art"

/* max. 20 Zeichen */
#define TXT_NO_SUPPLY          "|en|not supported"\
                               "|de|nicht untersttzt"

/* max. 20 Zeichen */
#define TXT_SPECIAL            "|en|special"\
                               "|de|spezial"


/* max. 20 Zeichen */
#define TXT_PM_COLLECT_SINGLE  "|en|Measured value"\
                               "|de|Mewert"
#define TXT_PM_COLLECT_DIFF    "|en|Mean value measurem."\
                               "|de|Mittelwertmessung"

#define HLP_PM_COLLECT_SINGLE  "|en|Sensor measurement - Measurement input "\
                                   "that receives one analog information."\
                               "|de|Analogwertmessung - Mewert-Erfassung mit "\
                                   "einem Analogeingang."

#define HLP_PM_COLLECT_DIFF    "|en|Differential measurement - Measurement "\
                                   "derived by computing the difference "\
                                   "between two analog inputs."\
                               "|de|Differenzmessung - Mewert ermittelt "\
                                   "durch Berechnung der Differenz von "\
                                   "zwei Analog-Eingngen."

#define HLP_PM_COLLECT_MID     "|en|Mean value measurement - Measurement "\
                                   "derived by computing the average of two "\
                                   "analog inputs."\
                               "|de|Mittelwertmessung - Mewert ermittelt "\
                                   "durch Berechnung des Mittelwertes von "\
                                   "zwei Analog-Eingngen."


/* max. 20 Zeichen */
#define TXT_PV_VALUE           "|en|Measured value"\
                               "|de|Mewert"
#define TXT_PV_PERCENT         "|en|Percent of range"\
                               "|de|Mespanne"
#define TXT_PV_MID_VALUE       "|en|Mean value"\
                               "|de|Mittelwert"
#define TXT_PV_DIFF_VALUE      "|en|Difference"\
                               "|de|Differenz"


#define HLP_PV_VALUE           "|en|Measured value - Measured value "\
                                   "that changes magnitude with respect to "\
                                   "time with no user intervention."\
                               "|de|Mewert - Mewert, der sich "\
                                   "anwenderunabhngig durch den "\
                                   "angeschlossenen Proze verndert."

#define HLP_PERCENT_RANGE      "|en|Percent of range - Digital value that is "\
                                   "proportional to the variable "\
                                   "DIGITAL_VALUE with respect to the range "\
                                   "defined by the LOWER_RANGE_VALUE and "\
                                   "UPPER_RANGE_VALUE. "\
                                   "The units of this variable are always "\
                                   "in percent."\
                               "|de|Prozent Mespanne - Megre, die den "\
                                   "Mewert als Prozentwert der Mespanne "\
                                   "darstellt, welche durch Meanfang und "\
                                   "-ende bestimmt ist."

#define HLP_UPPER_RANGE_VALUE  "|en|Upper range value - Defines the "\
                                   "operational endpoint from which the "\
                                   "variables ANALOG_VALUE, PERCENT_RANGE "\
                                   "are derived."\
                               "|de|Meende - Endpunkt fr das analoge "\
                                   "Ausgangssignal (=20mA) und den 100%-Punkt "\
                                   "des entsprechenden Prozentbereiches."

#define HLP_LOWER_RANGE_VALUE  "|en|Lower range value - Defines the "\
                                   "operational endpoint from which the "\
                                   "variables ANALOG_VALUE, PERCENT_RANGE "\
                                   "are derived."\
                               "|de|Meanfang - Anfangspunkt fr das analoge "\
                                   "Ausgangssignal (=4mA) und den 0%-Punkt "\
                                   "des entsprechenden Prozentbereiches."

#define HLP_UPPER_SENSOR_LIMIT "|en|Upper sensor limit value - Value that "\
                                   "defines the absolute upper endpoint "\
                                   "(largest magnitude) for the "\
                                   "UPPER RANGE VALUE."\
                               "|de|Obere Mebereichsgrenze - Dieser Wert "\
                                   "gibt die obere Grenze fr das "\
                                   "Mebereichsende an."

#define HLP_LOWER_SENSOR_LIMIT "|en|Lower sensor limit value - Value that "\
                                   "defines the absolute lower endpoint "\
                                   "(smallest magnitude) for the "\
                                   "LOWER RANGE VALUE."\
                               "|de|Untere Mebereichsgrenze - Dieser Wert "\
                                   "gibt die untere Grenze fr den "\
                                   "Mebereichsanfang an."

#define HLP_MINIMUM_SPAN       "|en|Minimum span value - Value that defines "\
                                   "the smallest absolute value for the "\
                                   "resulting figure derived from the "\
                                   "following equation "\
                                   "(UPPER RANGE VALUE - LOWER RANGE VALUE)."\
                               "|de|Minimale Mespanne - Die kleinste "\
                                   "zulssige Differenz zwischen Meanfang "\
                                   "und Meende."

#define HLP_DAMPING_VALUE      "|en|Damping value - Damping time applied to "\
                                   "both the variables DIGITAL_VALUE and "\
                                   "ANALOG_VALUE of output 'X'. The units of "\
                                   "this variable are always expressed in "\
                                   "seconds."\
                               "|de|Dmpfungszeit - Zeitkonstante der "\
                                   "Dmpfung, die auf den digitalen "\
                                   "Ausgangswert wie auch auf den analogen "\
                                   "Ausgang wirkt. Die Angabe erfolgt immer "\
                                   "in Sekunden."

#define HLP_REFER_JUNC_UNIT    "|en|Temp. unit of the reference junction "\
                                   "temperature - The temperature on the "\
                                   "terminal block of the field unit is "\
                                   "always stated in C during measurements "\
                                   "with internal or external reference "\
                                   "junction."\
                               "|de|Temp.-Einheit der Vergl.-stelle - Die "\
                                   "Temperatur am Klemmenblock des "\
                                   "Feldgertes wird bei Messungen mit "\
                                   "interner oder externer "\
                                   "Vergleichsstelle immer in C angegeben."

#define HLP_REFER_JUNC_VALUE   "|en|Reference junction temperature value - "\
                                   "Temperature associated with the "\
                                   "internal/external reference junction. At "\
                                   "an internal reference junction "\
                                   "the temperature of the connection "\
                                   "terminals of the transmitter will be "\
                                   "measured during measurements."\
                               "|de|Temperatur der Vergleichsstelle - "\
                                   "Temperatur der internen/externen "\
                                   "Vergleichsstelle. Bei einer internen "\
                                   "Vergleichsstelle wird die Temperatur "\
                                   "der Anschluklemmen des Meumformers bei "\
                                   "Messungen gemessen."


#define HLP_SENSOR1            "|en|Sensor 1 measurement -  Measurement "\
                                   "input 1 receives analog values. "\
                               "|de|Messung an Sensor 1 - Meeingang 1 nimmt "\
                                   "Analogwerte auf."

#define HLP_SENSOR2            "|en|Sensor 2 measurement - Measurement "\
                                   "input 2 receives analog values."\
                               "|de|Messung an Sensor 2 - Meeingang 2 nimmt "\
                                   "Analogwerte auf."

#define HLP_SNSR_UNITS         "|en|Unit - physical unit in which the "\
                                   "electrical value of the sensor is "\
                                   "expressed."\
                               "|de|Einheit - Einheit, in der der elekrische "\
                                   "Wert des Sensors angegeben wird."

#define HLP_SNSR1_VALUE        "|en|Sensor value - electrical value of the "\
                                   "sensor at the input."\
                               "|de|Sensorwert - Elektrischer Wert des "\
                                   "Sensors am Eingang."

#define HLP_SNSR2_VALUE        "|en|Sensor value - electrical value of the "\
                                   "sensor at the auxiliary input."\
                               "|de|Sensorwert - Elektrischer Wert des "\
                                   "Sensors am Hilfseingang."

#define TXT_FILTER             "|en|Mains filter"\
                               "|de|Netzspannungsfilter"

#define HLP_FILTER             "|en|Mains filter - frequency of the local  "\
                                   "mains to increase the rejection at the "\
                                   "input."\
                               "|de|Netzspannungsfilter - Frequenz der "\
                                   "Netzspannung um eine hohe "\
                                   "Unterdrckung am Eingang zu erreichen."

#define TXT_FILTER50           "|en|50 Hertz"\
                               "|de|50 Hertz"
#define TXT_FILTER60           "|en|60 Hertz"\
                               "|de|60 Hertz"

/* ************************************************************************** */

#define TXT_YES_NO             "|en|Yes;No"\
                               "|de|Ja;Nein"

#define TXT_UNIT_MA            "|en|mA"\
                               "|de|mA"

#define TXT_UNIT_SEK           "|en|s"\
                               "|de|s"

#define TXT_INVALID_INPUT      "|en|Invalid input"\
                               "|de|Unzulssige Eingabe"

#define TXT_DATA_SEND          "|en|Data being sent to unit, "\
                                   "please wait..."\
                               "|de|Die Daten werden zum Gert gesendet, "\
                                   "bitte warten..."

#define TXT_EEPROM_SPEICHERN   "|en|Should the data be made permanent?"\
                               "|de|Sollen die Daten netzausfallsicher "\
                                   "gespeichert werden?"

#define TXT_EEPROM_WAIT        "|en|Data is being made permanent, "\
                                   "please wait..."\
                               "|de|Daten werden netzausfallsicher "\
                                   "gespeichert, bitte warten..."

#define TXT_EEPROM_NO_SAVE     "|en|CAUTION - Data could not be made "\
                                   "permanent."\
                               "|de|WARNUNG - Die Daten konnten nicht "\
                                   "netzausfallsicher gespeichert werden."

#define TXT_RAM_DATA_LOSE      "|en|CAUTION - Data not made permanent "\
                                   "will be lost!"\
                               "|de|WARNUNG - Nicht netzausfallsicher "\
                                   "gespeicherte Daten gehen verloren!"

#define TXT_REMOVE_AUTO_LOOP   "|en|CAUTION - Loop should be removed from "\
                                   "automatic control!"\
                               "|de|WARNUNG - Ein angeschlossener Regelkreis "\
                                   "sollte auf Handbetrieb geschaltet werden!"

#define TXT_CONNECT_AUTO_LOOP  "|en|The connected loop can be put into "\
                                   "operation again."\
                               "|de|Die angeschlossene Regelung kann wieder "\
                                   "in Betrieb genommen werden."


/* max. 20 Zeichen */
#define TXT_SEND_DATA          "|en|Send data"\
                               "|de|Daten senden"

#define HLP_SEND_DATA          "|en|Send data - The new setting must "\
                                   "be first sent to the unit before "\
                                   "more data can be modified."\
                               "|de|Daten senden - Die neue Einstellung muss "\
                                   "erst zum Geraet gesendet werden, bevor "\
                                   "weitere Daten gendert werden."

#define TXT_PRESS_SEND_KEY     "|en|ATTENTION - The new setting must "\
                                   "be sent to the field unit. For this "\
                                   "purpose Press SEND key."\
                               "|de|ACHTUNG - Die neue Einstellung mu erst "\
                                   "zum Feldgert gesendet werden. Hierzu "\
                                   "Taste SENDE drcken."



/* max. 20 Zeichen */
#define TXT_CMOS               "|en|CMOS-Interface"\
                               "|de|CMOS-Schnittst."
/* max. 20 Zeichen */
#define TXT_RS232              "|en|RS232-Interface"\
                               "|de|RS232-Schnittst."

/* max. 12 Zeichen */
#define TXT_DEV_TH02           "|en|TH02/102/202"\
                               "|de|TH02/102/202"

/* max. 20 Zeichen */
#define TXT_SPEICHER_STATUS    "|en|Memory status"\
                               "|de|Speicherstatus"

#define TXT_EEPROM_READ        "|en|EEPROM read failure"\
                               "|de|EEPROM Lesefehler"
#define TXT_EEPROM_FAILURE     "|en|EEPROM failure"\
                               "|de|EEPROM Fehler"

/* max. 20 Zeichen */
#define TXT_INPUT_STATUS       "|en|Input status"\
                               "|de|Eingangsstatus"

#define TXT_ADC_NODATA         "|en|A/D Converter failure"\
                               "|de|A/D Wandler Fehler"

/* max. 20 Zeichen */
#define TXT_OP_STATUS          "|en|Balancing/Parameter"\
                               "|de|Abgleich/Parameter"

#define TXT_OP_ABGLEICH        "|en|Balancing active"\
                               "|de|Abgleich aktiv"
#define TXT_OP_E_ABGLEICH      "|en|Input balancing active"\
                               "|de|Eingangsabgleich aktiv"
#define TXT_OP_ABGL1_FAILURE   "|en|Balancing failure at input"\
                               "|de|Abgleichfehler am Eingang"
#define TXT_OP_ABGL2_FAILURE   "|en|Balancing failure at auxiliary input"\
                               "|de|Abgleichfehler am Hilfseingang"
#define TXT_OP_PARA_FAILURE    "|en|Parameter failure"\
                               "|de|Parameterfehler"

/* max. 20 Zeichen */
#define TXT_SENSOR_STATUS      "|en|Sensor status"\
                               "|de|Sensorstatus"

#define TXT_SNSR1_BRUCH        "|en|Sensor break at input"\
                               "|de|Sensorbruch am Eingang"
#define TXT_SNSR1_KURZ         "|en|Short circuit at input"\
                               "|de|Kurzschlu am Eingang"
#define TXT_SNSR1_UNTER        "|en|Input underrange"\
                               "|de|Eingang untersteuert"
#define TXT_SNSR1_UEBER        "|en|Input overrange"\
                               "|de|Eingang bersteuert"
#define TXT_SNSR2_BRUCH        "|en|Sensor break at auxiliary input"\
                               "|de|Sensorbruch am Hilfseingang"
#define TXT_SNSR2_KURZ         "|en|Short circuit at auxiliary input"\
                               "|de|Kurzschlu am Hilfseingang"
#define TXT_SNSR2_UNTER        "|en|Auxiliary input underrange"\
                               "|de|Hilfseingang untersteuert"
#define TXT_SNSR2_UEBER        "|en|Auxiliary input overrange"\
                               "|de|Hilfseingang bersteuert"

/* max. 20 Zeichen */
#define TXT_OUTPUT_STATUS      "|en|Output status"\
                               "|de|Ausgangsstatus"

#define TXT_AO_UNTERSTEUERT    "|en|Analog output underrange"\
                               "|de|Analogausgang untersteuert"
#define TXT_AO_UEBERSTEUERT    "|en|Analog output overrange"\
                               "|de|Analogausgang bersteuert"
#define TXT_AO_ERSATZWERT      "|en|Default value active"\
                               "|de|Ersatzwert aktiv"
#define TXT_AO_LETZTER_WERT    "|en|Keep last valid value"\
                               "|de|Letzten gltigen Wert halten"
#define TXT_AO_FIXED           "|en|Analog output fixed"\
                               "|de|Analogausgang fixiert"

#define TXT_STATUS_UPDATE      "|en|Caution! Data update in progress."\
                               "|de|Warnung! Die Daten werden zur Zeit "\
                                   "aktualisiert."



#define HLP_SPEICHER_STATUS    "|en|Memory failure - The instrument error can "\
                                   "possibly be remedied through self-test "\
                                   "correction.\n"\
                                   "If it continues to exist, it means the "\
                                   "unit is defective."\
                               "|de|Speicherfehler - Der Gertefehler kann "\
                                   "mglicherweise durch einen Selbsttest "\
                                   "korrigiert werden.\n"\
                                   "Tritt der Fehler weiterhin auf, liegt ein "\
                                   "Defekt am Gert vor."

#define HLP_INPUT_STATUS       "|en|Input failures - in the measurement "\
                                   "electronic are limit value infringements. "\
                                   "If the unit is being operated under "\
                                   "permissible ambient conditions, "\
                                   "the unit is defective."\
                               "|de|Eingangsfehler - In der Meelektronik "\
                                   "sind Grenzwerte verletzt. Wenn das "\
                                   "Gert unter zulssigen "\
                                   "Umgebungsbedingungen betrieben wird, "\
                                   "liegt ein Defekt am Gert vor."

#define HLP_OP_STATUS          "|en|Balancing/Parameter - The error status "\
                                   "of the balancing and configuration data "\
                                   "can be read out."\
                               "|de|Abgleich/Parameter - Der Fehlerzustand "\
                                   "der Abgleich- und Konfigurierdaten kann "\
                                   "abgelesen werden."

#define HLP_SENSOR_STATUS      "|en|Sensor status - The status of the active "\
                                   "sensors can be read out."\
                               "|de|Sensor-Status - Der Zustand der aktiven "\
                                   "Sensoren kann abgelesen werden."


#define HLP_OUTPUT_STATUS      "|en|Output status - The status of the "\
                                   "analog output can be read out."\
                               "|de|Ausgangsstatus - Der Zustand des "\
                                   "Analogausgangs kann abgelesen werden."

/* Grenzwerte */

#define TXT_THRESHOLD1         "|en|Threshold 1"\
                               "|de|Grenzwert 1"

#define TXT_THRESHOLD2         "|en|Threshold 2"\
                               "|de|Grenzwert 2"

#define HLP_THRESHOLD          "|en|Threshold - the measured percent of range will be monitored "\
                                   "for an over-/underranging of this threshold."\
                                   "The status can be read by HART only. There is NO influence "\
                                   "to the analog output."\
                               "|de|Grenzwert - der gemessene Prozentwert der Mespanne "\
                                   "wird auf ber-/Unterschreitung dieses Grenzwertes geprft."\
                                   "Der Status kann nur ber HART gelesen werden, "\
                                   "er hat KEINEN Einflu auf den Analogausgang."

#define TXT_THRESHOLD_STATUS   "|en|Threshold status"\
                               "|de|Grenzwertstatus"

#define HLP_THRESHOLD_STATUS   "|en|Threshold status - the status of the "\
                                   "thresholds can be read out."\
                               "|de|Grenzwertstatus - Der Zustand der"\
                                   "Grenzwerte kann abgelesen werden."

#define TXT_THRESHOLD1_OVER    "|en|Thresh. 1 overranged"\
                               "|de|Grenzw. 1 berschritten"
#define TXT_THRESHOLD1_UNDER   "|en|Thresh. 1 underranged"\
                               "|de|Grenzw. 1 unterschritten"
#define TXT_THRESHOLD2_OVER    "|en|Thresh. 2 overranged"\
                               "|de|Grenzw. 2 berschritten"
#define TXT_THRESHOLD2_UNDER   "|en|Thresh. 2 underranged"\
                               "|de|Grenzw. 2 unterschritten"

#define TXT_THRESHOLD1_RERROR  "|en|Invalid Threshold 1"\
                               "|de|Ungltiger Grenzwert 1"

#define TXT_THRESHOLD2_RERROR  "|en|Invalid Threshold 2"\
                               "|de|Ungltiger Grenzwert 2"

/* Zustand */

#define TXT_STATUS_OK          "|en|No malfunction signalled."\
                               "|de|Keine Fehlfunktionen gemeldet."

#define HLP_STATUS             "|en|Status - All sensor and instrument "\
                                   "failures recognised by the cyclical "\
                                   "monitoring unit are signalled. "\
                                   "The measurement operation is not "\
                                   "interrupted."\
                               "|de|Zustand - Alle durch die zyklische "\
                                   "berwachung erkannten Sensor- und "\
                                   "Gertefehler werden gemeldet. Der "\
                                   "Mebetrieb wird nicht gestrt."


/* Selbsttest */

#define TXT_MEASURE_STOP       "|en|CAUTION - The measurement operation "\
                                   "is interrupted."\
                               "|de|WARNUNG - Der Mebetrieb wird "\
                                   "unterbrochen."

#define TXT_SELFTEST_RUN       "|en|Self-test in progress, please wait..."\
                               "|de|Selbsttest wird durchgefhrt, bitte "\
                                   "warten..."

#define TXT_SELFTEST_BLOCKED   "|en|Transmitter self-test blocked."\
                               "|de|Meumformer im Selbsttest blockiert."

#define TXT_NO_SELFTEST        "|en|Self-test could not be carried out. "\
                               "|de|Selbsttest konnte nicht durchgefhrt "\
                                   "werden."

#define TXT_SELFTEST_OK        "|en|Self-test completed. No malfunctions "\
                                   "discovered."\
                               "|de|Selbsttest beendet. Keine Fehlfunktionen "\
                                   "festgestellt."

#define HLP_SELF_TEST          "|en|Self-test - Transmitter self-test "\
                                   "in progress. The analog output is "\
                                   "frozen. Recognised failures are "\
                                   "displayed."\
                               "|de|Selbsttest - Der Meumformer fhrt einen "\
                                   "Selbsttest durch. Der Analogausgang wird "\
                                   "eingefroren. Erkannte Fehler werden "\
                                   "angezeigt."


/* MU-RESET */

/* max. 20 Zeichen */
#define TXT_MASTER_TEST        "|en|Transmitter reset"\
                               "|de|Meumf.-Neustart"

#define TXT_RESET_WAIT         "|en|Master reset in progress, please wait..."\
                               "|de|Meumformer wird neu gestartet, bitte "\
                                   "warten..."

#define TXT_RESET_BLOCKED      "|en|Transmitter reset blocked."\
                               "|de|Meumformer im Neustart blockiert."

#define TXT_NO_MASTER_TEST     "|en|Reset could not be carried out."\
                               "|de|Neustart konnte nicht durchgefhrt werden."

#define HLP_MASTER_TEST        "|en|Transmitter reset - The transmitter is "\
                                   "restarted. Non-permanent stored data are "\
                                   "lost. Self-test is subsequently conducted."\
                               "|de|Meumf.-Neustart - Der Meumformer wird "\
                                   "neu gestartet. Nicht netzausfallsicher "\
                                   "gespeicherte Daten gehen dabei verloren. "\
                                   "Anschlieend wird ein Selbsttest "\
                                   "ausgefhrt."


/* PRESET (Werkseinstellung) */

/* max. 20 Zeichen */

#define TXT_USER_DATA_LOSE     "|en|CAUTION - All user data are "\
                                   "lost (consult Help)!"\
                               "|de|WARNUNG - Alle Anwenderdaten gehen "\
                                   "verloren (Hilfe beachten)!"


/* Werte beaufschlagen */

#define TXT_APPLY_4MA_INPUT        "|en|Apply new 4mA input"\
                                   "|de|Neuen 4mA-Eingang anlegen!"

#define TXT_APPLY_20MA_INPUT       "|en|Apply new 20mA input"\
                                   "|de|Neuen 20mA-Eingang anlegen!"

#define TXT_APPLIED_SENS_FAIL      "|en|FAILURE - Sensor failure or sensor "\
                                       "not in valid range!"\
                                   "|de|FEHLER - Sensorfehler oder Sensor "\
                                       "nicht im gltigen Bereich!"


/* Leitungsabgleich */

/* max. 20 Zeichen */
#define TXT_WIRE_TRIM              "|en|Lead balancing"\
                                   "|de|Leitungsabgleich"

#define TXT_LABGL_MAX_2            "|en|The lead resistance may not "\
                                       "exceed 10 Ohm!"\
                                   "|de|Der Leitungswiderstand darf max. "\
                                       "10 Ohm betragen!"

#define TXT_LABGL_MAX_3            "|en|The difference of the conductor "\
                                       "resistance may not exceed 10Ohm max.!"\
                                   "|de|Die Differenz der Aderwiderstnde "\
                                       "darf max. 10Ohm betragen!"

/* max. 18;18 Zeichen */
#define TXT_LABGL_SELECT           "|en|Input;Auxiliary input"\
                                   "|de|Eingang;Hilfseingang"

#define TXT_LABGL_SHORT_ALL        "|en|Short-circuit all connection lines "\
                                       "to all sensors!"\
                                   "|de|Alle Anschlussleitungen"\
                                       "an allen Sensoren kurzschlieen!"

#define TXT_LABGL_SHORT_INP        "|en|Short-circuit all connection lines "\
                                       "on sensor!"\
                                   "|de|Alle Anschlussleitungen"\
                                       "am Sensor kurzschlieen!"

#define TXT_LABGL_NO_TRIM          "|en|The parameter setting does not permit "\
                                       "any lead balancing."\
                                   "|de|Die Parametrierung erlaubt keinen "\
                                       "Leitungsabgleich."

#define TXT_LABGL_WAIT             "|en|Lead balancing in progress, "\
                                       "please wait..."\
                                   "|de|Leitungsabgleich wird gestartet, "\
                                       "bitte warten..."

#define TXT_NO_LABGL               "|en|Lead balancing could not be "\
                                       "carried out!"\
                                   "|de|Leitungsabgleich konnte nicht "\
                                       "durchgefhrt werden!"

#define TXT_LABGL_NO_SUCCESS       "|en|FAILURE - Lead balancing could not "\
                                       "be carried out successfully!"\
                                   "|de|FEHLER - Leitungsabgleich konnte "\
                                       "nicht erfolgreich durchgefhrt werden!"

#define TXT_LABGL_SUCCESS          "|en|Balancing successfully carried out. "\
                                       "Remove short-circuit on sensor."\
                                   "|de|Abgleich konnte erfolgreich "\
                                       "durchgefhrt werden. Kurzschluss "\
                                       "am Sensor entfernen."


#define TXT_LABGL_TIP_1            "|en|Check sensor connection!"\
                                   "|de|Ueberpruefen Sie den Sensoranschlu!"

#define TXT_LABGL_TIP_2            "|en|Choose the right mainsfilter."\
                                   "|de|Whlen Sie den richtigen Netzfilter."


#define HLP_WIRE_TRIM              "|en|Lead balancing - The "\
                                       "resistance of the connection lines to "\
                                       "sensor can be compensated for. This "\
                                       "step is only necessary "\
                                       "for measurement resistors "\
                                       "in 2-wire circuitry."\
                                   "|de|Leitungsabgleich - Der "\
                                       "Widerstand der Anschluleitungen zum "\
                                       "Sensor kann kompensiert werden. Diese "\
                                       "Manahme ist nur bei Mewiderstnden "\
                                       "in 2-Leiter-Schaltung "\
                                       "notwendig."


/* reset_parameter */

/* max. 20 Zeichen */
#define TXT_RESET_PARAMETER        "|en|Data reset"\
                                   "|de|Daten zurcksetzen"

#define HLP_RESET_PARAMETER        "|en|Data reset - All data, which were "\
                                       "not made permanent are reset to their "\
                                       "original values. "\
                                       "This allows the old data "\
                                       "to be restored when a parameter "\
                                       "setting is interrupted."\
                                   "|de|Daten zurcksetzen - Alle Daten, die "\
                                       "nicht netzausfallsicher gespeichert "\
                                       "wurden, werden auf ihre "\
                                       "ursprnglichen Werte zurckgesetzt. "\
                                       "Damit knnen die alten Daten "\
                                       "restauriert werden, wenn eine "\
                                       "Parametrierung abgebrochen wurde."

#define TXT_RESET_PARA_WAIT        "|en|Data reset in progress, please "\
                                       "wait..."\
                                   "|de|Daten werden zurckgesetzt, bitte "\
                                       "warten..."

#define TXT_NO_PARA_RESET          "|en|FAILURE - The data could not be "\
                                       "reset!"\
                                   "|de|FEHLER - Die Daten konnten nicht "\
                                       "zurckgesetzt werden!"

/* Eingangsparametrierung */

/* max. 20 Zeichen */
#define TXT_INPUT_RANGE            "|en|Input assignment"\
                                   "|de|Eingangsbelegung"

#define HLP_INPUT_RANGE            "|en|Input assignment - measuring range of "\
                                       "the transmitter at the input."\
                                   "|de|Eingangsbelegung - Mebereich des "\
                                       "Meumformers am Eingang."

/* max. 20 Zeichen */
#define TXT_LOCAL_MESSART          "|en|Type of measurement"\
                                   "|de|Meart"

#define HLP_LOCAL_MESSART          "|en|Type of measurement - The setting "\
                                       "determines, whether single- or "\
                                       "multi-channel measurement is active."\
                                   "|de|Meart - Die Einstellung legt fest, "\
                                       "ob ein- oder mehrkanalige Messung "\
                                       "aktiv ist."\

/* max. 20 Zeichen */
#define TXT_EINFACH                "|en|Single-channel"\
                                   "|de|Einfach"
#define TXT_DIFFERENZ              "|en|Difference"\
                                   "|de|Differenz"
#define TXT_MITTELWERT             "|en|Average value"\
                                   "|de|Mittelwert"
#define TXT_MITTELW_OHNE           "|en| without redundancy"\
                                   "|de|Mittelw. ohne Red."
#define TXT_MITTELW_MIT            "|en| with redundancy"\
                                   "|de|Mittelw. mit Redund."


/* max. 20 Zeichen */
#define TXT_SENSOR_NO_MONITOR      "|en|No monitoring"\
                                   "|de|Keine berwachung"
#define TXT_SENSOR_BRUCH           "|en|Break monitoring"\
                                   "|de|Bruchberwachung"
#define TXT_SENSOR_KURZ            "|en|Short circuit(<5Ohm)"\
                                   "|de|Kurzschlu (<5Ohm)"
#define TXT_SENSOR_BRUCH_KURZ      "|en|Break/short circuit"\
                                   "|de|Bruch u. Kurzschlu"


/* max. 20 Zeichen */
#define TXT_CONFIG_SENSOR          "|en|Sensor config."\
                                   "|de|Sensor-Konfig."

#define HLP_CONFIG_SENSOR          "|en|Input parameter - the parameters for "\
                                       "wiring to the input (sensor type, "\
                                       "etc.) can be fixed via the function."\
                                   "|de|Eingangsparameter - ber die Funktion "\
                                       "knnen die Parameter zur Beschaltung "\
                                       "des Eingangs (Sensortyp, etc.) "\
                                       "festgelegt werden."

/* max. 20 Zeichen */
#define TXT_PROCESS_UNIT           "|en|Process unit"\
                                   "|de|Prozeeinheit"

/* max. 20 Zeichen */
#define TXT_REF_JUNC_TYP           "|en|Reference junction"\
                                   "|de|Vergleichsstelle"

#define HLP_REF_JUNC_TYP           "|en|Reference junction - The setting "\
                                       "determines the type of reference "\
                                       "junction during measurements with "\
                                       "thermocouples. "\
                                       "Always select 'WITHOUT' for "\
                                       "measurements witout thermocouples."\
                                   "|de|Vergleichsstelle - Die Einstellung "\
                                       "bestimmt die Art der Vergleichsstelle "\
                                       "bei Messungen mit Thermoelementen. "\
                                       "Bei Messungen ohne Thermoelemente ist "\
                                       "immer 'OHNE' zu whlen."


/* max. 20 Zeichen */
#define TXT_REF_JUNC_OHNE          "|en|without"\
                                   "|de|ohne"
#define TXT_REF_JUNC_EXTERN        "|en|external"\
                                   "|de|extern"
#define TXT_REF_JUNC_INTERN        "|en|internal"\
                                   "|de|intern"


#define TXT_RANGE_CHANGED          "|en|CAUTION - The measuring range is "\
                                       "matched to the new permissible limits."\
                                   "|de|WARNUNG - Der Messbereich wird an die "\
                                       "neuen zulssigen Grenzen angepasst."


#define TXT_ACKN_TEST_RANGE        "|en|CAUTION - Check measuring range "\
                                       "before switching on a connected "\
                                       "control loop again."\
                                   "|de|ACHTUNG - Mebereich berprfen, "\
                                       "bevor ein angeschlossener Regelkreis "\
                                       "wieder eingeschaltet wird."


/* max. 20 Zeichen */
#define TXT_FAILURE_CONTROL        "|en|Failure monitoring"\
                                   "|de|Fehlerberwachung"

#define HLP_FAILURE_CONTROL        "|en|Failure monitoring - The setting "\
                                       "determines if the analog output "\
                                       "should react to certain failure "\
                                       "states in the transmitter."\
                                   "|de|Fehlerberwachung - Die Einstellung "\
                                       "legt fest, ob der Analogausgang auf "\
                                       "bestimmte Fehlerzustnde im "\
                                       "Meumformer reagieren soll."


/* max. 20 Zeichen */
#define TXT_SENSOR_FEHLER          "|en|Sensor failure"\
                                   "|de|Sensorfehler"
#define TXT_SENS_DEV_FEHLER        "|en|Sensor-/dev. failure"\
                                   "|de|Sensor-/Gertefehler"
#define TXT_DEV_FEHLER             "|en|Device failure"\
                                   "|de|Gertefehler"
#define TXT_NO_CONTROL             "|en|No monitoring"\
                                   "|de|Keine berwachung"

/* max. 20 Zeichen */
#define TXT_FAILURE_SIGNAL         "|en|Signalling"\
                                   "|de|Signalisierung"

#define HLP_FAILURE_SIGNAL         "|en|Signalling - The setting determines "\
                                       "if a failure shall be signalled via "\
                                       "the analog output."\
                                   "|de|Signalisierung - Die Einstellung legt "\
                                       "fest, wie ein Fehler ber den "\
                                       "Analogausgang gemeldet wird."

/* max. 20 Zeichen */
#define TXT_SIGNAL_HIGH            "|en|Overrange"\
                                   "|de|bersteuern"
#define TXT_SIGNAL_LOW             "|en|underrange"\
                                   "|de|untersteuern"
#define TXT_SIGNAL_ALTER           "|en|Default value"\
                                   "|de|Ersatzwert"
#define TXT_SIGNAL_HOLD            "|en|Hold the last value"\
                                   "|de|letzten Wert halten"

/* max. 20 Zeichen */
#define TXT_CONFIG_OUTPUT          "|en|Output config."\
                                   "|de|Ausgang konfig."

#define HLP_CONFIG_OUTPUT          "|en|Configuration of analog output - The "\
                                       "setting determines the behaviour of "\
                                       "the output in case of failure."\
                                   "|de|Analogausgang konfigurieren - Die "\
                                       "Einstellung bestimmt das Verhalten "\
                                       "des Ausgangs im Fehlerfall."

#define TXT_INPUT_UNDER_VAL        "|en|Underrange value\n"\
                                       "valid range: 3.6..4mA"\
                                   "|de|Untersteuerwert\n"\
                                       "Gltiger Bereich: 3,6..4mA"
#define TXT_INPUT_OVER_VAL         "|en|Overrange value\n"\
                                       "valid range: 20..23.6mA"\
                                   "|de|Uebersteuerwert\n"\
                                       "Gltiger Bereich: 20..23,6mA"



/*
 *   THxxxCO.DDL
 */


/* VARIABLE Messart */

#define TXT_OHM50_EINF             "|en|ohm single 50hz"\
                                   "|de|Ohm einfach 50Hz"
#define TXT_OHM50_DIFF             "|en|ohm difference 50hz"\
                                   "|de|Ohm Differenz 50Hz"
#define TXT_OHM50_MITT             "|en|ohm average 50hz"\
                                   "|de|Ohm Mittelwert 50Hz"
#define TXT_OHM60_EINF             "|en|ohm single 60hz"\
                                   "|de|Ohm einfach 60Hz"
#define TXT_OHM60_DIFF             "|en|ohm difference 60hz"\
                                   "|de|Ohm Differenz 60Hz"
#define TXT_OHM60_MITT             "|en|ohm average 60hz"\
                                   "|de|Ohm Mittelwert 60Hz"

#define TXT_MV50_EINF              "|en|mV single 50hz"\
                                   "|de|mV einfach 50Hz"
#define TXT_MV50_DIFF              "|en|mV difference 50hz"\
                                   "|de|mV Differenz 50Hz"
#define TXT_MV50_MITT              "|en|mV average 50hz"\
                                   "|de|mV Mittelwert 50Hz"
#define TXT_MV50_EINF_VGEXT        "|en|mV single ext.cjc 50hz"\
                                   "|de|mV einfach ext.VG 50Hz"
#define TXT_MV50_DIFF_VGEXT        "|en|mV difference ext.cjc 50hz"\
                                   "|de|mV Differenz ext.VG 50Hz"
#define TXT_MV50_MITT_VGEXT        "|en|mV average ext.cjc 50hz"\
                                   "|de|mV Mittelwert ext.VG 50Hz"
#define TXT_MV50_EINF_VGINT        "|en|mV single int.cjc 50hz"\
                                   "|de|mV einfach int.VG 50Hz"
#define TXT_MV50_DIFF_VGINT        "|en|mV difference int.cjc 50hz"\
                                   "|de|mV Differenz int.VG 50Hz"
#define TXT_MV50_MITT_VGINT        "|en|mV average int.cjc 50hz"\
                                   "|de|mV Mittelwert int.VG 50Hz"

#define TXT_MV60_EINF              "|en|mV single 60hz"\
                                   "|de|mV einfach 60Hz"
#define TXT_MV60_DIFF              "|en|mV difference 60hz"\
                                   "|de|mV Differenz 60Hz"
#define TXT_MV60_MITT              "|en|mV average 60hz"\
                                   "|de|mV Mittelwert 60Hz"
#define TXT_MV60_EINF_VGEXT        "|en|mV single ext.cjc 60hz"\
                                   "|de|mV einfach ext.VG 60Hz"
#define TXT_MV60_DIFF_VGEXT        "|en|mV difference ext.cjc 60hz"\
                                   "|de|mV Differenz ext.VG 60Hz"
#define TXT_MV60_MITT_VGEXT        "|en|mV average ext.cjc 60hz"\
                                   "|de|mV Mittelwert ext.VG 60Hz"
#define TXT_MV60_EINF_VGINT        "|en|mV single int.cjc 60hz"\
                                   "|de|mV einfach int.VG 60Hz"
#define TXT_MV60_DIFF_VGINT        "|en|mV difference int.cjc 60hz"\
                                   "|de|mV Differenz int.VG 60Hz"
#define TXT_MV60_MITT_VGINT        "|en|mV average int.cjc 60hz"\
                                   "|de|mV Mittelwert int.VG 60Hz"

#define TXT_OHM_KLEIN              "|en|0..500ohms"\
                                   "|de|0..500Ohm"
#define TXT_OHM_GROSS              "|en|0..5000ohms"\
                                   "|de|0..5000Ohm"
#define TXT_MV_KLEIN               "|en|-125..125mv"\
                                   "|de|-125..125mV"
#define TXT_MV_GROSS               "|en|-125..1200mv"\
                                   "|de|-125..1200mV"

#define TXT_OHM_EINF               "|en|ohm"\
                                   "|de|Ohm"
#define TXT_OHM_DIFF               "|en|ohm - difference   "\
                                   "|de|Ohm - Differenz"
#define TXT_OHM_MITT               "|en|ohm - average value"\
                                   "|de|Ohm - Mittelwert"
#define TXT_MV_EINF                "|en|mV"\
                                   "|de|mV"
#define TXT_MV_DIFF                "|en|mV - difference"\
                                   "|de|mV - Differenz"
#define TXT_MV_MITT                "|en|mV - average value"\
                                   "|de|mV - Mittelwert"
#define TXT_AL_EINF                "|en|single"\
                                   "|de|einfach"
#define TXT_AL_DIFF                "|en|difference value"\
                                   "|de|Differenz"
#define TXT_AL_MITT                "|en|average value"\
                                   "|de|Mittelwert"

/* max. 20 Zeichen */
#define TXT_MODE_CJC               "|en|Reference junction"\
                                   "|de|Vergleichsstelle"

#define HLP_MODE_CJC               "|en|Reference junction - The setting "\
                                       "determines the type of reference "\
                                       "junction during measurements with "\
                                       "thermocouples. "\
                                   "|de|Vergleichsstelle - Die Einstellung "\
                                       "bestimmt die Art der Vergleichsstelle "\
                                       "bei Messungen mit Thermoelementen. "\

/* max. 20 Zeichen */
#define TXT_CJC_OFF                "|en|without"\
                                   "|de|ohne"
#define TXT_CJC_EXTERN             "|en|external"\
                                   "|de|extern"
#define TXT_CJC_INTERN             "|en|internal"\
                                   "|de|intern"


#define HLP_MESSART                "|en|Type of measurement - Setting of "\
                                       "vital input parameters on transmitter."\
                                   "|de|Meart - Einstellung wesentlicher "\
                                       "Eingangsparameter am Meumformer."


/* VARIABLE sensor_type */

/* max. 20 Zeichen */
#define TXT_SENSOR_TYPE            "|en|Sensor type"\
                                   "|de|Sensortyp"

/* max. 20 Zeichen */
#define TXT_LINEAR                 "|en|Linear"\
                                   "|de|Linear"
#define TXT_LINEARLO               "|en|Linear low range   "\
                                   "|de|Linear kleiner Ber."
#define TXT_LINEARHI               "|en|Linear high range  "\
                                   "|de|Linear groer Ber. "
#define TXT_FREISTIL               "|en|Free style"\
                                   "|de|Freistil"
#define TXT_PT100                  "|en|Pt 100   a=0.003850"\
                                   "|de|Pt 100   a=0.003850"
#define TXT_PT100_3916             "|en|Pt 100   a=0.003916"\
                                   "|de|Pt 100   a=0.003916"
#define TXT_PT100_3920             "|en|Pt 100   a=0.003920"\
                                   "|de|Pt 100   a=0.003920"
#define TXT_PT100_3923             "|en|Pt 100   a=0.003923"\
                                   "|de|Pt 100   a=0.003923"
#define TXT_NI100                  "|en|Ni 100    DIN 43760"\
                                   "|de|Ni 100    DIN 43760"
#define TXT_CU100                  "|en|Cu 100             "\
                                   "|de|Cu 100             "
#define TXT_TYP_B                  "|en|Type B Pt30Rh-Pt6Rh"\
                                   "|de|Typ B  Pt30Rh-Pt6Rh"
#define TXT_TYP_C                  "|en|Type C     W5-W26Rh"\
                                   "|de|Typ C      W5-W26Rh"
#define TXT_TYP_D                  "|en|Type D     W3-W25Rh"\
                                   "|de|Typ D      W3-W25Rh"
#define TXT_TYP_E                  "|en|Type E    NiCr-CuNi"\
                                   "|de|Typ E     NiCr-CuNi"
#define TXT_TYP_J                  "|en|Type J      Fe-CuNi"\
                                   "|de|Typ J       Fe-CuNi"
#define TXT_TYP_K                  "|en|Type K      Ni-CrNi"\
                                   "|de|Typ K       Ni-CrNi"
#define TXT_TYP_L                  "|en|Type L      Fe-CuNi"\
                                   "|de|Typ L       Fe-CuNi"
#define TXT_TYP_N                  "|en|Type N  NiCrSi-NiSi"\
                                   "|de|Typ N   NiCrSi-NiSi"
#define TXT_TYP_R                  "|en|Type R    Pt13Rh-Pt"\
                                   "|de|Typ R     Pt13Rh-Pt"
#define TXT_TYP_S                  "|en|Type S    Pt10Rh-Pt"\
                                   "|de|Typ S     Pt10Rh-Pt"
#define TXT_TYP_T                  "|en|Type T      Cu-CuNi"\
                                   "|de|Typ T       Cu-CuNi"
#define TXT_TYP_U                  "|en|Type U      Cu-CuNi"\
                                   "|de|Typ U       Cu-CuNi"


#define HLP_SENSOR_TYP             "|en|Sensor type - Type of currently "\
                                       "connected sensor. Depending on the "\
                                       "type of selected characteristic line, "\
                                       "the measured value is influenced."\
                                   "|de|Sensortyp - Art des derzeit "\
                                       "angeschlossenen Sensors. Durch die "\
                                       "Wahl der Kennlinie wird die Korrektur "\
                                       "der Mewerte beeinflut."


/* wire_no */

/* max. 20 Zeichen */
#define TXT_WIRE_NO                "|en|Sensor connection"\
                                   "|de|Sensorschaltung"

#define HLP_WIRE_NO                "|en|Sensor connection - States the number "\
                                       "of wires, via which the sensor is "\
                                       "connected to the transmitter."\
                                   "|de|Sensorschaltung - Gibt die Anzahl der "\
                                       "Adern an, ber die der Sensor mit dem "\
                                       "Meumformer verbunden ist."


/* n_sensor */

/* max. 20 Zeichen */
#define TXT_N_SENSOR               "|en|Number of sensors"\
                                   "|de|Anzahl der Sensoren"

/* max. 20 Zeichen */
#define TXT_01_SENSOR              "|en|1 Sensor"\
                                   "|de|1 Sensor"
#define TXT_02_SENSOR              "|en|2 Sensors"\
                                   "|de|2 Sensoren"
#define TXT_03_SENSOR              "|en|3 Sensors"\
                                   "|de|3 Sensoren"
#define TXT_04_SENSOR              "|en|4 Sensors"\
                                   "|de|4 Sensoren"
#define TXT_05_SENSOR              "|en|5 Sensors"\
                                   "|de|5 Sensoren"
#define TXT_06_SENSOR              "|en|6 Sensors"\
                                   "|de|6 Sensoren"
#define TXT_07_SENSOR              "|en|7 Sensors"\
                                   "|de|7 Sensoren"
#define TXT_08_SENSOR              "|en|8 Sensors"\
                                   "|de|8 Sensoren"
#define TXT_09_SENSOR              "|en|9 Sensors"\
                                   "|de|9 Sensoren"
#define TXT_10_SENSOR              "|en|10 Sensors"\
                                   "|de|10 Sensoren"
#define TXT_HALB_SENSOR            "|en|0.5 Sensor"\
                                   "|de|0.5 Sensor"
#define TXT_17_SENSOR              "|en|0.2 Sensor"\
                                   "|de|0.2 Sensor"
#define TXT_18_SENSOR              "|en|0.1 Sensor"\
                                   "|de|0.1 Sensor"
#define TXT_19_SENSOR              "|en|1.2 Sensor"\
                                   "|de|1.2 Sensor"

#define HLP_N_SENSOR               "|en|Number of sensors - States the number "\
                                       "of sensors which are connected in "\
                                       "series at every input. A multiple "\
                                       "number of the built-in characteristic "\
                                       "lines can be realised (e.g. 10*Pt100 "\
                                       "= Pt1000)."\
                                   "|de|Anzahl der Sensoren - Gibt die Anzahl "\
                                       "der Sensoren an, die an jedem Eingang "\
                                       "in Reihe geschaltet sind. Vielfache "\
                                       "der eingebauten Kennlinien knnen "\
                                       "realisiert werden (z.B. 10*Pt100 = "\
                                       "Pt1000)."


/* Sensorberwachung */

/* max. 20 Zeichen */
#define TXT_SENSOR_MONITOR         "|en|Sensor monitoring"\
                                   "|de|Sensorberwachung"

#define HLP_SENSOR_MONITOR         "|en|Sensor monitoring - With this setting "\
                                       "the monitoring of the sensors can be "\
                                       "limited or released.\n"\
                                       "An internal reference junction is "\
                                       "always monitored."\
                                   "|de|Sensorberwachung - Mit dieser "\
                                       "Einstellung kann die berwachung der "\
                                       "Sensoren beschrnkt oder freigegeben "\
                                       "werden.\n"\
                                       "Eine interne Vergleichsstelle wird "\
                                       "immer berwacht."

#define TXT_NO_MONITOR             "|en|No sensor monitoring"\
                                   "|de|Keine Sensor-berwachung"
#define TXT_EINGANG_BRUCH          "|en|Break monitoring at input"\
                                   "|de|Bruchberwachung am Eingang"
#define TXT_H_EING_BRUCH           "|en|Break monitoring at auxiliary input"\
                                   "|de|Bruchberwachung am Hilfseingang"
#define TXT_VERG_BRUCH             "|en|Break monitoring of the reference "\
                                       "junction"\
                                   "|de|Bruchberwachung der  Vergleichsstelle"
#define TXT_EINGANG_KURZ           "|en|Short-circuit monitoring at input"\
                                   "|de|Kurzschlu.-berw. am Eingang"
#define TXT_H_EING_KURZ            "|en|Short-circuit monitoring at "\
                                       "auxiliary input"\
                                   "|de|Kurzschlu.-berw. am Hilfsingang"
#define TXT_VERG_KURZ              "|en|Short-circuit monitoring of the "\
                                       "reference junction"\
                                   "|de|Kurzschlu.-berw. der Vergl.-Stelle"
#define TXT_EINGANG_BRUCH_KURZ     "|en|Break and short-circuit monitoring at "\
                                       "input"\
                                   "|de|Bruch- und Kurzschlu-berw. am Eingang"
#define TXT_H_EING_BRUCH_KURZ      "|en|Break and short-circuit monitoring at "\
                                       "auxiliary input"\
                                   "|de|Bruch- und Kurzschlu-berw. am "\
                                       "Hilfseingang"
#define TXT_VERG_BRUCH_KURZ        "|en|Break and short-circuit monitoring of "\
                                       "reference junction"\
                                   "|de|Bruch- und Kurzschlu-berw. der "\
                                       "Vergl.-Stelle"
#define TXT_EING_BRUCH_KURZ        "|en|Break and short-circuit monitoring at "\
                                       "input"\
                                   "|de|Bruch- und Kurzschlu-berw. am Eingang"
#define TXT_ALL_BRUCH              "|en|Break monitoring of all sensors"\
                                   "|de|Bruchberwachung aller Sensoren"
#define TXT_ALL_KURZ               "|en|Short-circuit of all sensors"\
                                   "|de|Kurzschlu-berw. aller Sensoren"
#define TXT_ALL_BRUCH_KURZ         "|en|Break and short circuit monitoring of "\
                                       "all sensors"\
                                   "|de|Bruch- und Kurzschlu-berw. aller "\
                                       "Sensoren"


/* Temperatur der externen Vergleichsstelle */

/* max. 20 Zeichen */
#define TXT_EXT_REF_TEMP           "|en|ext. ref. junction"\
                                   "|de|ext. Vergl.-Temp."

#define TXT_PROMPT_EXT_TEMP        "|en|ext. ref. junction [degC]:"\
                                   "|de|ext. Vergl.-Temperatur [C]:"

#define HLP_EXT_REF_TEMP           "|en|External reference junction - "\
                                       "The value states the temperature "\
                                       "of the external reference junction. "\
                                       "The input is always made in degC!"\
                                   "|de|Externe Vergl.-Temperatur - Der Wert "\
                                       "gibt die Temperatur der externen "\
                                       "Vergleichsstelle an. Die Eingabe "\
                                       "erfolgt immer in C!"


/* Kommando #131 */

#define TXT_INVALID_MESSART        "|en|Invalid measure. type"\
                                   "|de|Ungltige Meart"
#define TXT_INVALID_N_SENSOR       "|en|Invalid number of sensors"\
                                   "|de|Ungltige Sensor-Anzahl"
#define TXT_INVALID_MONITOR        "|en|Invalid sensor monitoring"\
                                   "|de|Ungltige Sensorberwachung"
#define TXT_REF_TEMP_TOO_LOW       "|en|Temperature of reference junction "\
                                       "too low"\
                                   "|de|Temperatur der Vergleichsstelle "\
                                       "zu klein"
#define TXT_REF_TEMP_TOO_HIGH      "|en|Temperature of the reference junction "\
                                       "too high"\
                                   "|de|Temperatur der Vergleichsstelle zu gro"


/* out_select */

/* max. 20 Zeichen */
#define TXT_OUT_4_20MA             "|en|4..20mA"\
                                   "|de|4..20mA"

#define HLP_OUT_SELECT             "|en|Analog output - The device is only "\
                                       "available as signal output 4..20mA. "\
                                       "An under- or overrange exceeding this "\
                                       "range is however possible."\
                                   "|de|Analog-Ausgang - Das Gert ist nur "\
                                       "mit Strom-Ausgang 4..20mA verfgbar. "\
                                       "Eine ber diesen Bereich "\
                                       "hinausgehende Unter- oder "\
                                       "bersteuerung ist jedoch mglich."


/* out_under */

/* max. 20 Zeichen */
#define TXT_OUT_UNDER              "|en|Underrange value "\
                                   "|de|Untersteuerwert"

#define HLP_OUT_UNDER              "|en|Underrange value - The control range "\
                                       "is limited by the underrange value. "\
                                       "In case of failure signal, the value "\
                                       "is also accepted by means of "\
                                       "underranging."\
                                   "|de|Untersteuerwert - Der "\
                                       "Aussteuerbereich wird durch den "\
                                       "Untersteuerwert begrenzt. Der Wert "\
                                       "wird ebenfalls bei "\
                                       "Fehlersignalisierung durch "\
                                       "Untersteuerung angenommen."


/* out_over */

/* max. 20 Zeichen */
#define TXT_OUT_OVER               "|en|Overrange value"\
                                   "|de|bersteuerwert"

#define HLP_OUT_OVER               "|en|Overrange value - The control range "\
                                       "is limited by the overrange value. "\
                                       "In case of failure signal, the value "\
                                       "is also accepted by means of "\
                                       "overranging."\
                                   "|de|bersteuerwert - Der Aussteuerbereich "\
                                       "wird durch den bersteuerwert "\
                                       "begrenzt. Der Wert wird ebenfalls bei "\
                                       "Fehlersignalisierung durch "\
                                       "bersteuerung angenommen."


/* alter_selector */

/* max. 20 Zeichen */
#define TXT_ALTER_SELECTOR         "|en|Failure signalling "\
                                   "|de|Fehlersignalisierung"

#define TXT_S_UEBER                "|en|Overrange in case of sensor failure"\
                                   "|de|bei Sensorfehler bersteuern"
#define TXT_S_UNTER                "|en|Underrange in case of sensor failure"\
                                   "|de|bei Sensorfehler untersteuern"
#define TXT_S_ERSATZ               "|en|Default value in case of sensor "\
                                       "failure"\
                                   "|de|bei Sensorfehler Ersatzwert"
#define TXT_S_HALTEN               "|en|Keep value in case of sensor failure "\
                                   "|de|bei Sensorfehler Wert halten"
#define TXT_SG_UEBER               "|en|Overrange in case of device or sensor "\
                                       "error"\
                                   "|de|bei Gerte- oder Sensorfehler "\
                                       "bersteuern"
#define TXT_SG_UNTER               "|en|Underrange in case of device or "\
                                       "sensor failure"\
                                   "|de|bei Gerte- oder Sensorfehler "\
                                       "untersteuern"
#define TXT_SG_ERSATZ              "|en|Default value in case of device or "\
                                       "sensor failure"\
                                   "|de|bei Gerte- oder Sensorfehler "\
                                       "Ersatzwert"
#define TXT_SG_HALTEN              "|en|Keep value in case of device or "\
                                       "sensor failure"\
                                   "|de|bei Gerte- oder Sensorfehler Wert "\
                                       "halten"
#define TXT_SG_NOTHING             "|en|Pass on value in case of device or "\
                                       "sensor failure "\
                                   "|de|bei Gerte- oder Sensorfehler Wert "\
                                       "weiterreichen"

#define HLP_ALTER_SELECTOR         "|en|Failure signalling - The setting "\
                                       "indicates the strategy for signalling "\
                                       "a failure."\
                                   "|de|Fehlersignalisierung - Die "\
                                       "Einstellung gibt die Strategie zur "\
                                       "Signalisierung eines Fehlers an."


/* alter_value */

/* max. 20 Zeichen */
#define TXT_ALTER_VALUE            "|en|Default value"\
                                   "|de|Ersatzwert"

#define HLP_ALTER_VALUE            "|en|Default value - in case of failure, "\
                                       "the analog output is set on the "\
                                       "programmed value if the matching "\
                                       "error strategy was selected."\
                                   "|de|Ersatzwert - Im Fehlerfall wird der "\
                                       "Analogausgang auf den eingetragenen "\
                                       "Wert gesetzt, wenn die passende "\
                                       "Fehlerstrategie gewhlt wurde."


/* Kommando #133 */

#define TXT_INV_ERROR_STRATEGIE    "|en|Invalid failure strategy"\
                                   "|de|Ungltige Fehlerstrategie"
#define TXT_INV_ALTER_VALUE        "|en|Invalid default value"\
                                   "|de|Ungltiger Ersatzwert"


/* info_nummer */

/* max. 20 Zeichen */
#define TXT_INFO_NUMMER            "|en|Text number"\
                                   "|de|Text-Nummer"

#define HLP_INFO_NUMMER            "|en|Text number -\n"\
                                       "0: internal Codes\n"\
                                       "1: Sensor name\n"\
                                       "2: Catalog number"\
                                   "|de|Text-Nummer -\n"\
                                       "0: interne Kodierungen\n"\
                                       "1: Sensorname\n"\
                                       "2: Bestellnummer"


/* textx */

/* max. 20 Zeichen */
#define TXT_INFO_TEXT              "|en|Info-Text"\
                                   "|de|Info-Text"

#define HLP_INFO_TEXT              "|en|Info-Text -\n"\
                                       "0: internal codes\n"\
                                       "1: Sensor name\n"\
                                       "2: Catalog number"\
                                   "|de|Info-Text -\n"\
                                       "0: interne Kodierungen\n"\
                                       "1: Sensorname\n"\
                                       "2: Bestellnummer"

/* preset_ctl */

/* max. 20 Zeichen */
#define TXT_PRESET_CTL             "|en|PRESET control"\
                                   "|de|PRESET-Steuerung"

/* max. 20 Zeichen */

#define TXT_PRESET_JUST            "|en|Balancing data"\
                                   "|de|Abgleichdaten"

#define HLP_PRESET_CTL             "|en|PRESET control - Control code for the "\
                                       "PRESET function."\
                                   "|de|PRESET-Steuerung - Steuerkode fr die "\
                                       "PRESET-Funktion."


/* unit */

#define HLP_JUST_UNIT              "|en|Unit - Unit for the set point"\
                                   "|de|Einheit - Einheit fr den Sollwert"


/* kanal */

/* max. 20 Zeichen */
#define TXT_JUST_KANAL             "|en|Signal input"\
                                   "|de|Meeingang"

#define HLP_JUST_KANAL             "|en|Signal input - The setting determines "\
                                       "the signal input which must be "\
                                       "balanced."\
                                   "|de|Meeingang - Die Einstellung bestimmt "\
                                       "den Meeingang, der abgeglichen "\
                                       "werden soll."


/* sollwert */

#define HLP_JUST_SOLLWERT          "|en|Set point - The value states the "\
                                       "(e.g. simulated via a reference) "\
                                       "input signal."\
                                   "|de|Sollwert - Der Wert gibt das "\
                                       "(z.B. ber eine Referenz simulierte) "\
                                       "Eingangssignal an."


/* Kommando #163 */

#define TXT_INVALID_CHANNEL        "|en|Invalid signal input"\
                                   "|de|Ungltiger Meeingang"

#define TXT_INVALID_UNIT           "|en|Invalid unit"\
                                   "|de|Ungltige Einheit"

/* Sensorname alias Kennlinienname */

/* max. 20 Zeichen */
#define TXT_SENSOR_NAME            "|en|Curve name"\
                                   "|de|Kennlinienname"

#define HLP_SENSOR_NAME            "|en|Curve name - The function permits "\
                                       "the input of a curve name when "\
                                       "using the Free style sensortype."\
                                   "|de|Kennlinienname - Die Funktion erlaubt "\
                                       "die Eingabe eines Kennliniennamens bei "\
                                       "der Verwendung des Freistil Sensortyps."

#define TXT_SENSOR_NAME_NOT_READ   "|en|FAILURE - Curve name could not "\
                                       "be read."\
                                   "|de|FEHLER - Kennlinienname konnte nicht "\
                                       "gelesen werden."

#define TXT_SENSOR_NAME_NOT_WRITE  "|en|FAILURE - Curve name could not "\
                                       "be written."\
                                   "|de|FEHLER - Kennlinienname konnte nicht "\
                                       "geschrieben werden."



/* Version */

/* max. 20 Zeichen */
#define TXT_VERSION                "|en|Version 2.00"\
                                   "|de|Version 2.00"

/* max. 20 Zeichen */
#define TXT_LANGUAGE               "|en|English"\
                                   "|de|Deutsch"

#define HLP_LANGUAGE               "|en|Language of strings"\
                                   "|de|Landessprache der Texte"


/* TH02fs.DDL  Free style Configuration */

#define TXT_CURVE_NO_EDIT          "|en|The Free style sensortype must be activated "\
                                       "before accessing the tiepoints."\
                                   "|de|Der Freistil Sensortyp muss vor dem "\
                                       "Zugriff auf die Sttzpunkte aktiv sein."

#define VXT_CURVEV_PROMPT          "|en|Tiepoint %{idx}/32\nIN =%[+10.3f]{tmp_X}%{0}\nOUT=%[+10.3f]{tmp_Y}%{1}"\
                                   "|de|Sttzpunkt %{idx}/32\nEIN=%[+10.3f]{tmp_X}%{0}\nAUS=%[+10.3f]{tmp_Y}%{1}"

#define VXT_CURVEV_SELECT          "|en|next tiepoint;previous tiepoint;Change values;Send curve"\
                                   "|de|Nchster Sttzp.;Voheriger Sttzp.;Werte ndern;Kennl. schreiben"

#define VXT_CURVEE_X               "|en|Tiepoint %{idx}\nInput value[%{0}]"\
                                   "|de|Sttzpunkt %{idx}\nEingangswert[%{0}]"


#define VXT_CURVEE_Y               "|en|Tiepoint %{idx}\nOutput value[%{1}]"\
                                   "|de|Sttzpunkt %{idx}\nAusgangswert[%{1}]"


#define TXT_FREESTYLE_CONFIG       "|en|Free style config."\
                                   "|de|Freistil Konfig."

#define TXT_EDIT_CURVE             "|en|Tiepoints"\
                                   "|de|Sttzpunkte"

#define HLP_EDIT_CURVE             "|en|Tiepoints - review and "\
                                       "edit the linearisation "\
                                       "characteristics of the "\
                                       "Free style sensortype."\
                                   "|de|Sttzpunkte - Anzeige und "\
                                       "Bearbeitung der Linearisierung "\
                                       "des Freistil Sensortyps."

#define TXT_CURVEX_ERROR           "|en|Curve is NOT valid. "\
                                       "INput values are not "\
                                       "monotone ascent order."\
                                   "|de|Kennlinie ist NICHT gltig. "\
                                       "EINgangswerte sind nicht "\
                                       "streng monoton steigend."

#define TXT_CURVEY_ERROR           "|en|Curve is NOT valid. "\
                                       "OUTput values are not "\
                                       "monotone."\
                                   "|de|Kennlinie ist NICHT gltig. "\
                                       "AUSgangswerte sind nicht "\
                                       "streng monoton."

#define TXT_CURVE_READ             "|en|Read curve, please wait..."\
                                   "|de|Lese Kennlinie, bitte warten..."

#define TXT_CURVE_READ_ERROR       "|en|Error at reading Curve."\
                                   "|de|Fehler bei Lesen der "\
                                       "Kennlinie."

#define TXT_CURVE_WRITE            "|en|Send curve, please wait..."\
                                   "|de|Schreibe Kennlinie, bitte warten..."
#define TXT_CURVE_WRITE_ERROR      "|en|Error at sending Curve."\
                                   "|de|Fehler bei Schreiben der "\
                                       "Kennlinie."

#define TXT_CURVE_WRITTEN          "|en|Curve was successfully "\
                                       "send to the device."\
                                   "|de|Kennlinie wurde erfolgreich "\
                                       "im Gert gespeichert."

#define TXT_TIEPOINT_X01           "|en|Tiepoint_01-IN "\
                                   "|de|Sttzpunkt_01-EIN"
#define TXT_TIEPOINT_Y01           "|en|Tiepoint_01-OUT"\
                                   "|de|Sttzpunkt_01-AUS"
#define TXT_TIEPOINT_X02           "|en|Tiepoint_02-IN "\
                                   "|de|Sttzpunkt_02-EIN"
#define TXT_TIEPOINT_Y02           "|en|Tiepoint_02-OUT"\
                                   "|de|Sttzpunkt_02-AUS"
#define TXT_TIEPOINT_X03           "|en|Tiepoint_03-IN "\
                                   "|de|Sttzpunkt_03-EIN"
#define TXT_TIEPOINT_Y03           "|en|Tiepoint_03-OUT"\
                                   "|de|Sttzpunkt_03-AUS"
#define TXT_TIEPOINT_X04           "|en|Tiepoint_04-IN "\
                                   "|de|Sttzpunkt_04-EIN"
#define TXT_TIEPOINT_Y04           "|en|Tiepoint_04-OUT"\
                                   "|de|Sttzpunkt_04-AUS"
#define TXT_TIEPOINT_X05           "|en|Tiepoint_05-IN "\
                                   "|de|Sttzpunkt_05-EIN"
#define TXT_TIEPOINT_Y05           "|en|Tiepoint_05-OUT"\
                                   "|de|Sttzpunkt_05-AUS"
#define TXT_TIEPOINT_X06           "|en|Tiepoint_06-IN "\
                                   "|de|Sttzpunkt_06-EIN"
#define TXT_TIEPOINT_Y06           "|en|Tiepoint_06-OUT"\
                                   "|de|Sttzpunkt_06-AUS"
#define TXT_TIEPOINT_X07           "|en|Tiepoint_07-IN "\
                                   "|de|Sttzpunkt_07-EIN"
#define TXT_TIEPOINT_Y07           "|en|Tiepoint_07-OUT"\
                                   "|de|Sttzpunkt_07-AUS"
#define TXT_TIEPOINT_X08           "|en|Tiepoint_08-IN "\
                                   "|de|Sttzpunkt_08-EIN"
#define TXT_TIEPOINT_Y08           "|en|Tiepoint_08-OUT"\
                                   "|de|Sttzpunkt_08-AUS"
#define TXT_TIEPOINT_X09           "|en|Tiepoint_09-IN "\
                                   "|de|Sttzpunkt_09-EIN"
#define TXT_TIEPOINT_Y09           "|en|Tiepoint_09-OUT"\
                                   "|de|Sttzpunkt_09-AUS"
#define TXT_TIEPOINT_X10           "|en|Tiepoint_10-IN "\
                                   "|de|Sttzpunkt_10-EIN"
#define TXT_TIEPOINT_Y10           "|en|Tiepoint_10-OUT"\
                                   "|de|Sttzpunkt_10-AUS"
#define TXT_TIEPOINT_X11           "|en|Tiepoint_11-IN "\
                                   "|de|Sttzpunkt_11-EIN"
#define TXT_TIEPOINT_Y11           "|en|Tiepoint_11-OUT"\
                                   "|de|Sttzpunkt_11-AUS"
#define TXT_TIEPOINT_X12           "|en|Tiepoint_12-IN "\
                                   "|de|Sttzpunkt_12-EIN"
#define TXT_TIEPOINT_Y12           "|en|Tiepoint_12-OUT"\
                                   "|de|Sttzpunkt_12-AUS"
#define TXT_TIEPOINT_X13           "|en|Tiepoint_13-IN "\
                                   "|de|Sttzpunkt_13-EIN"
#define TXT_TIEPOINT_Y13           "|en|Tiepoint_13-OUT"\
                                   "|de|Sttzpunkt_13-AUS"
#define TXT_TIEPOINT_X14           "|en|Tiepoint_14-IN "\
                                   "|de|Sttzpunkt_14-EIN"
#define TXT_TIEPOINT_Y14           "|en|Tiepoint_14-OUT"\
                                   "|de|Sttzpunkt_14-AUS"
#define TXT_TIEPOINT_X15           "|en|Tiepoint_15-IN "\
                                   "|de|Sttzpunkt_15-EIN"
#define TXT_TIEPOINT_Y15           "|en|Tiepoint_15-OUT"\
                                   "|de|Sttzpunkt_15-AUS"
#define TXT_TIEPOINT_X16           "|en|Tiepoint_16-IN "\
                                   "|de|Sttzpunkt_16-EIN"
#define TXT_TIEPOINT_Y16           "|en|Tiepoint_16-OUT"\
                                   "|de|Sttzpunkt_16-AUS"
#define TXT_TIEPOINT_X17           "|en|Tiepoint_17-IN "\
                                   "|de|Sttzpunkt_17-EIN"
#define TXT_TIEPOINT_Y17           "|en|Tiepoint_17-OUT"\
                                   "|de|Sttzpunkt_17-AUS"
#define TXT_TIEPOINT_X18           "|en|Tiepoint_18-IN "\
                                   "|de|Sttzpunkt_18-EIN"
#define TXT_TIEPOINT_Y18           "|en|Tiepoint_18-OUT"\
                                   "|de|Sttzpunkt_18-AUS"
#define TXT_TIEPOINT_X19           "|en|Tiepoint_19-IN "\
                                   "|de|Sttzpunkt_19-EIN"
#define TXT_TIEPOINT_Y19           "|en|Tiepoint_19-OUT"\
                                   "|de|Sttzpunkt_19-AUS"
#define TXT_TIEPOINT_X20           "|en|Tiepoint_20-IN "\
                                   "|de|Sttzpunkt_20-EIN"
#define TXT_TIEPOINT_Y20           "|en|Tiepoint_20-OUT"\
                                   "|de|Sttzpunkt_20-AUS"
#define TXT_TIEPOINT_X21           "|en|Tiepoint_21-IN "\
                                   "|de|Sttzpunkt_21-EIN"
#define TXT_TIEPOINT_Y21           "|en|Tiepoint_21-OUT"\
                                   "|de|Sttzpunkt_21-AUS"
#define TXT_TIEPOINT_X22           "|en|Tiepoint_22-IN "\
                                   "|de|Sttzpunkt_22-EIN"
#define TXT_TIEPOINT_Y22           "|en|Tiepoint_22-OUT"\
                                   "|de|Sttzpunkt_22-AUS"
#define TXT_TIEPOINT_X23           "|en|Tiepoint_23-IN "\
                                   "|de|Sttzpunkt_23-EIN"
#define TXT_TIEPOINT_Y23           "|en|Tiepoint_23-OUT"\
                                   "|de|Sttzpunkt_23-AUS"
#define TXT_TIEPOINT_X24           "|en|Tiepoint_24-IN "\
                                   "|de|Sttzpunkt_24-EIN"
#define TXT_TIEPOINT_Y24           "|en|Tiepoint_24-OUT"\
                                   "|de|Sttzpunkt_24-AUS"
#define TXT_TIEPOINT_X25           "|en|Tiepoint_25-IN "\
                                   "|de|Sttzpunkt_25-EIN"
#define TXT_TIEPOINT_Y25           "|en|Tiepoint_25-OUT"\
                                   "|de|Sttzpunkt_25-AUS"
#define TXT_TIEPOINT_X26           "|en|Tiepoint_26-IN "\
                                   "|de|Sttzpunkt_26-EIN"
#define TXT_TIEPOINT_Y26           "|en|Tiepoint_26-OUT"\
                                   "|de|Sttzpunkt_26-AUS"
#define TXT_TIEPOINT_X27           "|en|Tiepoint_27-IN "\
                                   "|de|Sttzpunkt_27-EIN"
#define TXT_TIEPOINT_Y27           "|en|Tiepoint_27-OUT"\
                                   "|de|Sttzpunkt_27-AUS"
#define TXT_TIEPOINT_X28           "|en|Tiepoint_28-IN "\
                                   "|de|Sttzpunkt_28-EIN"
#define TXT_TIEPOINT_Y28           "|en|Tiepoint_28-OUT"\
                                   "|de|Sttzpunkt_28-AUS"
#define TXT_TIEPOINT_X29           "|en|Tiepoint_29-IN "\
                                   "|de|Sttzpunkt_29-EIN"
#define TXT_TIEPOINT_Y29           "|en|Tiepoint_29-OUT"\
                                   "|de|Sttzpunkt_29-AUS"
#define TXT_TIEPOINT_X30           "|en|Tiepoint_30-IN "\
                                   "|de|Sttzpunkt_30-EIN"
#define TXT_TIEPOINT_Y30           "|en|Tiepoint_30-OUT"\
                                   "|de|Sttzpunkt_30-AUS"
#define TXT_TIEPOINT_X31           "|en|Tiepoint_31-IN "\
                                   "|de|Sttzpunkt_31-EIN"
#define TXT_TIEPOINT_Y31           "|en|Tiepoint_31-OUT"\
                                   "|de|Sttzpunkt_31-AUS"
#define TXT_TIEPOINT_X32           "|en|Tiepoint_32-IN "\
                                   "|de|Sttzpunkt_32-EIN"
#define TXT_TIEPOINT_Y32           "|en|Tiepoint_32-OUT"\
                                   "|de|Sttzpunkt_32-AUS"


#define HLP_TIEPOINT_X             "|en|Tiepoint inputvalue - "\
                                       "States the inputvalue of this tiepoint in "\
                                       "ohms or millivolts. All tiepoints "\
                                       "must be given and the values must "\
                                       "be monotone ascent order."\
                                   "|de|Sttzpunkt Eingangswert - "\
                                       "Gibt den Eingangswert dieses Sttzpunktes in "\
                                       "Ohm oder mV an. Alle Sttzpunkte mssen "\
                                       "angegeben werden und die Werte mssen "\
                                       "monoton steigend sein."
#define HLP_TIEPOINT_Y             "|en|Tiepoint outputvalue - "\
                                       "States the outputvalue of this tiepoint in "\
                                       "degC. All tiepoints must be given and the "\
                                       "values must be monotone ascent or descent order."\
                                   "|de|Sttzpunkt Ausgangswert - "\
                                       "Gibt den Ausgangswert dieses Sttzpunktes in "\
                                       "C an. Alle Sttzpunkte mssen angegeben "\
                                       "werden und die Werte mssen monoton "\
                                       "steigend oder fallend sein."
                                
#define TXT_CURVE_X                "|en|Inputvalues"\
                                   "|de|Eingangswerte"
#define HLP_CURVE_X                "|en|Inputvalues of the"\
                                       "Freestyle curve in"\
                                       "ohms or millivolts."\
                                   "|de|Eingangswerte der"\
                                       "Freistil Kennlinie in"\
                                       "Ohm oder mV."
#define TXT_CURVE_Y                "|en|Outputvalues"\
                                   "|de|Ausgangswerte"
#define HLP_CURVE_Y                "|en|Outputvalues of the"\
                                       "Freestyle curve in"\
                                       "degree celsius."\
                                   "|de|Ausgangswerte der"\
                                       "Freistil Kennlinie in C"


/* TH02tp.DLL  ( Input )Trimming and Preset-Functions */

#define VXT_TRIMC_PROMPT1          "|en|Connect the input to a %{0}-calibrator with %{1}"\
                                   "|de|Verbinde den %{0}-Kalibrator mit dem Eingang in %{1}"

#define VXT_TRIMC_PROMPT2          "|en|Connect the auxiliary input to a %{0}-calibrator with %{1}"\
                                   "|de|Verbinde den %{0}-Kalibrator mit dem Hilfseingang in %{1}"

#define VXT_TRIMSPR_PROMPT         "|en|Set calibrator to a value in the range of\n%{2} to %{3} %{0}."\
                                   "|de|Kalibrator auf einen Wert von\n%{2} bis %{3} %{0} einstellen."

#define TXT_TRIMA1_PROMPT          "|en|Enter the value for the 1st set point"\
                                   "|de|Wert fr den 1. Abgleichpunkt eingeben"

#define TXT_TRIMA2_PROMPT          "|en|Enter the value for the 2nd set point"\
                                   "|de|Wert fr den 2. Abgleichpunkt eingeben"

#define TXT_INPUT_TRIM             "|en|A/D trim"\
                                   "|de|Eingangsabgleich"

#define HLP_INPUT_TRIM             "|en|Analog to Digital trim - Allows the "\
                                       "calibration of a selected Analog Input with "\
                                       "an external reference ( precision calibrator )."\
                                   "|de|Eingangsabgleich - Ermglicht den Abgleich eines "\
                                       "Analogen Eingangs mithilfe einer externen Referenz "\
                                       "( Przisionskalibrator )."

#define TXT_TRIMIN_SELK            "|en|Select input to trim"\
                                   "|de|Whle Eingang fr Abgleich"

#define TXT_TRIMIN_SELKO           "|en|Input;Auxiliary input"\
                                   "|de|Eingang;Hilfseingang"

#define TXT_TRIMIN_SHORT2          "|en|Short-circuit the connection "\
                                       "lines of the auxiliary input !"\
                                   "|de|Anschlussleitungen des "\
                                       "Hilfseingangs kurzschlieen !"

#define TXT_TRIMIN_SHORT1          "|en|Short-circuit the connection "\
                                       "lines of the input !"\
                                   "|de|Anschlussleitungen des "\
                                       "Eingangs kurzschlieen !"

#define TXT_TRIMIN_NO_SUCCESS      "|en|FAILURE - A/D trim could not "\
                                       "be carried out successfully!"\
                                   "|de|FEHLER - Eingangsabgleich konnte "\
                                       "nicht erfolgreich durchgefhrt werden!"

#define TXT_TRIMIN_TIP_1           "|en|Check sensor connection!"\
                                   "|de|Ueberpruefen Sie den Sensoranschlu!"

#define TXT_TRIMIN_WAIT            "|en|A/D trim in progress, "\
                                       "please wait..."\
                                   "|de|Eingangsabgleich wird gestartet, "\
                                       "bitte warten..."

#define TXT_NO_TRIMIN              "|en|A/D trim could not be "\
                                       "carried out!"\
                                   "|de|Eingangsabgleich konnte nicht "\
                                       "durchgefhrt werden!"

#define TXT_TRIMIN_SUCCESS         "|en|A/D trim successfully carried out. "\
                                       "Remove calibration connections."\
                                   "|de|Eingangsabgleich konnte erfolgreich "\
                                       "durchgefhrt werden. Kalibrator "\
                                       "kann entfernt werden."

#define TXT_INVALID_PRESETCODE     "|en|Invalid Preset-Code"\
                                   "|de|Ungltiger Preset-Code"

#define TXT_ER_PRESET_MFGTRIM      "|en|FAILURE - Factory trimmings "\
                                       "could not be restored.\n"\
                                       "CAUTION: The actual calibration of "\
                                       "the device is INVALID!"\
                                   "|de|FEHLER - Werksabgleich konnte "\
                                       "nicht reaktiviert werden.\n"\
                                       "WARNUNG: Der momentane Abgleich des "\
                                       "Messumformers ist ungltig!"

#define TXT_PRESET_ALL             "|en|Factory preset"\
                                   "|de|Werkseinstellung"

#define TXT_PRESET_MFGTRIM         "|en|Reset trimmings"\
                                   "|de|Werksabgleich"

#define TXT_NO_PRESET_ALL          "|en|Factory preset could not be "\
                                       "carried out!"\
                                   "|de|Werkseinstellung konnte nicht "\
                                       "reaktiviert werden!"

#define TXT_NO_PRESET_MFGTRIM      "|en|Reset trimmings could not be "\
                                       "carried out!"\
                                   "|de|Werksabgleich konnte nicht "\
                                       "reaktiviert werden!"

#define TXT_PRESET_ALL_SUCCESS     "|en|Factory preset successfully "\
                                       "carried out."\
                                   "|de|Werkseinstellung konnte erfolgreich "\
                                       "reaktiviert werden."

#define TXT_PRESET_MFGTRIM_SUCCESS "|en|Reset trimmings successfully "\
                                       "carried out."\
                                   "|de|Werksabgleich konnte erfolgreich "\
                                       "reaktiviert werden."

#define TXT_LOSE_PRESET_ALL        "|en|CAUTION - ALL user data are "\
                                       "lost (consult Help)!"\
                                   "|de|WARNUNG - ALLE Anwenderdaten gehen "\
                                       "verloren (Hilfe beachten)!"

#define TXT_LOSE_PRESET_MFGTRIM    "|en|CAUTION - ALL user trimmings are "\
                                       "lost (consult Help)!"\
                                   "|de|WARNUNG - ALLE Anwenderableichdaten "\
                                       "gehen verloren (Hilfe beachten)!"

#define TXT_RUN_PRESET_ALL         "|en|Factory preset in "\
                                       "progress, please wait..."\
                                   "|de|Werkseinstellung wird reaktiviert "\
                                       ", bitte warten..."

#define TXT_RUN_PRESET_MFGTRIM     "|en|Reset trimmings in progress, please "\
                                       "wait..."\
                                   "|de|Werksabgleich wird reaktiviert, bitte "\
                                       "warten..."

#define HLP_PRESET_ALL             "|en|Factory preset - All calibration data "\
                                       "are overwritten with the basic data "\
                                       "fixed during manufacture. The parameter "\
                                       "data are reset to the standard values.\n"\
                                       "CAUTION: The user data are thus lost "\
                                       "permanently."\
                                   "|de|Werkseinstellung - Alle Abgleichdaten "\
                                       "werden mit den bei der Herstellung "\
                                       "festgelegten Grundabgleichdaten "\
                                       "berschrieben. Die Parametrierdaten "\
                                       "werden auf Standardwerte zurckgesetzt.\n"\
                                       "WARNUNG: Die Anwenderdaten gehen damit "\
                                       "unwiederbringlich verloren."

#define HLP_PRESET_MFGTRIM         "|en|Reset trimmings - All calibration data "\
                                       "are overwritten with the basic data "\
                                       "fixed during manufacture. The parameter "\
                                       "data is unchanged."\
                                   "|de|Werksabgleich - Alle Abgleichdaten "\
                                       "werden mit den bei der Herstellung "\
                                       "festgelegten Grundabgleichdaten "\
                                       "berschrieben. Die Parametrierdaten "\
                                       "werden nicht verndert."

#endif /* __THXXX_DCT__ */

