/*##CODE-DATEI
;-------------------------------------------------------------------------------
;##Copyright        :  ABB Automation Products GmbH
;
;-------------------------------------------------------------------------------
;##System           :  CONTRANS T
;##Systemkomponente :  Temperaturmessumformer TH02
;                      (Transmitter spez. Dokument: Rev. 1)
;-------------------------------------------------------------------------------
;##Programm         :  HC-DDL
;##Modul            :  TH02
;##Pfad/Datei       :  TH02.DDL
;##Library/Overlay  :  -/-
;##Programmierer    :  K.Pose / PLC-Alz
;##Erst.-Datum      :  22.09.1999
;##Version/Datum    :  01.00 / 02.03.2000
;-------------------------------------------------------------------------------
;##Beschreibung     :  Basis zur Definition der Geraetebeschreibung fuer den
;                      Temperatur-Messumformer TH02.
;
;                      In dieser Datei erfolgt das Einbinden der weiteren
;                      notwendigen Beschreibungen sowie die Definition von
;                      ARRAY's, COLLECTION's, etc., wofuer die auch immer gut
;                      sein sollen.
;
;##SPECEND
;-------------------------------------------------------------------------------
;###*/

/* ************************************************************************** */

MANUFACTURER        26,			/* ABB, */
DEVICE_TYPE         8,			/* TH02, */

DEVICE_REVISION 	1,
DD_REVISION			4

#define DEVICE_TITLE [table_sensor_abb_rh02]

/* Includes ------------------------------------------------------ */

// #include "SIHA.inc"
#include "SI_HlpM.inc"
#include "SI_FileM.inc"
#include "SI_OptM.inc"
#include "bi_codes.h"
#include "macros.ddl"

/* Verlauf ------------------------------------------------------- */

#define YT1_LABEL	[PV_VALUE]
#define YT1_VALUE	primary_measurement_digital_value
#define	YT1_LRV		primary_measurement_lower_range_value
#define YT1_URV		primary_measurement_upper_range_value

#define YT2_LABEL	[PV_PERCENT]
#define YT2_VALUE	primary_measurement_percent_range
#define	YT2_LRV		limit_min
#define YT2_URV		limit_max

#include "SI_YT.inc"

/* Ident ------------------------------------------------------- */


VARIABLE manufacturer_id
	{
	  TYPE ENUMERATED
	  {
		{ 22,  [ABB] },
		{ 26 , [ABB] }
	  }
	}

VARIABLE device_type
	{
	  TYPE ENUMERATED
	  {
		{ 8 , "TH02" }
	  }
	}

/* ************************************************************************** */

#ifndef __TH02__      /* ************************************************** */
#define __TH02__      /*   Hier wird die Geraetebeschreibung fuer den       */
#endif                /*   TH02 festgelegt.                                 */
                      /* ************************************************** */


#define __HC_275__      /* ************************************************** */
                        /*   Schaltet VARIABLEn, METHODs, etc. ab, die im     */
                        /*   HC275 zu Stoerungen oder unerwarteten            */
                        /*   Reaktionen fuehren.                              */
                        /*                                                    */
                        /*   Vielleicht koennen andere Bediengeraete diese    */
                        /*   Teile der Geraetebeschreibung benutzen.          */
                        /* ************************************************** */

/* ************************************************************************** */

//=============================================================================
//  MENU Bar
//=============================================================================

MENU Menu_Main_Specialist
{
  LABEL [main_menu];
  ITEMS {
    Menu_File,
    Menu_S_Device,
    Menu_S_View,
    Menu_Options,
    Menu_Help
  }
}

//-------------------------------------

MENU Menu_Main_Maintenance
{
  LABEL [main_menu];
  ITEMS	{
    Menu_File,
    Menu_M_Device,
    Menu_M_View,
    Menu_Options,
    Menu_Help
  }
}

//-----------------------------------------------------------------------------
//    Menu: File
//-----------------------------------------------------------------------------

MENU Menu_File
{
  LABEL [menu_File];
  ITEMS {
    std_Save,
    SEPARATOR,
    std_Eigenschaften,
    SEPARATOR,
    std_Print,
    std_PrintPreview,
    std_PrintSetup,
    std_PageSetup,
    std_Schriftfelder,
    SEPARATOR,
    std_Exit
  }
}

/*---------------------------------------------------------------------*/
/*    Menu: Device													   */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_CommWay,
		SEPARATOR,
		OnlineDialog_Device_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,
		std_LoadinPC,
		SEPARATOR,
		loop_test,												/* method */
		self_test,												/* method */
		master_reset,											/* method */
		master_test,
		configuration_flag_reset,								/* method */
		SEPARATOR,
		OnlineDialog_burn_eeprom,								/* Online Dialog */
		SEPARATOR,
		OnlineDialog_measuring_elements,
		OnlineDialog_signal_conditioning,
		OnlineDialog_analog_output,
		OnlineDialog_hart_output,
		OnlineDialog_device_info,
		OnlineDialog_transmitter_trim,							/* Online Dialog */
		SEPARATOR,
		OnlineDialog_hart_comm2									/* Online Dialog */
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_CommWay,
	    SEPARATOR,
		std_LoadinDevice,
		std_LoadinPC
	}
}
METHOD std_CommWay
{
	LABEL		[menu_Device_CommWay];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

METHOD master_reset
{
	LABEL		[master_reset];
	HELP		[master_reset_help];
	CLASS		INPUT;
	DEFINITION
	{
		int		choice;
		char	status[3];
		char	disp_string1[60];
		char	disp_string2[60];
		int		slen1;
		int		slen2;

		slen1=60;
		slen2=60;

		get_dictionary_string(master_reset_execute,disp_string1,slen1);
		get_dictionary_string(yes_no,disp_string2,slen2);

		choice= SELECT_FROM_LIST(disp_string1, disp_string2);
		if ( choice == 0 )
		{
			add_abort_method(return_to_normal);
			IGNORE_ALL_RESPONSE_CODES();
			send (42, status);
			if ((status[STATUS_RESPONSE_CODE] >1)|| status[STATUS_COMM_STATUS] || status[STATUS_DEVICE_STATUS] )
			{
				if (status[STATUS_RESPONSE_CODE] > 1)
				{
					display_response_status(41, status[STATUS_RESPONSE_CODE]);
				}
				if (status[STATUS_COMM_STATUS])
				{
					display_comm_status(status[STATUS_COMM_STATUS]);
				}
				if (status[STATUS_DEVICE_STATUS])
				{
					display_device_status(status[STATUS_DEVICE_STATUS]);
				}
				process_abort();
			}

			else
			{
				get_dictionary_string(master_reset_ok, disp_string1, slen1);
				ACKNOWLEDGE(disp_string1);
			}
		}
	}
}

METHOD configuration_flag_reset
{
	LABEL		[configuration_flag_reset];
	HELP		[configuration_flag_reset_help];
	CLASS		INPUT;
	DEFINITION
	{
		int		choice;
		char	disp_string1[60];
		char	disp_string2[60];
		int		slen1;
		int		slen2;

		slen1=60;
		slen2=60;

		get_dictionary_string(configuration_flag_reset_execute, disp_string1, slen1);
		get_dictionary_string(yes_no, disp_string2, slen2);

		choice= SELECT_FROM_LIST(disp_string1, disp_string2);
		if ( choice == 0 )
		{
			send_command(38);
		}
	}
}

MENU OnlineDialog_burn_eeprom
{
	LABEL		[menu_burn_eeprom];
	ITEMS
	{
		burn_eeprom   /* method */
	}
}


MENU OnlineDialog_transmitter_trim
{
	LABEL		[menu_dialog_transmitter_trim];
	ITEMS
	{
		dac_trim,             /* method */
		scaled_dac_trim,      /* method */
		input_trim,           /* method */
		preset_mfgtrim,       /* method */
		preset_all            /* method */
	}
}


/*---------------------------------------------------------------------*/
/*    Menu: View													   */
/*---------------------------------------------------------------------*/


MENU Menu_S_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_S_diagnosis, 
    SEPARATOR,
    OnlineWindow_yt,
  }
}

MENU Menu_M_View
{
  LABEL [menu_View];
  ITEMS {
    OnlineWindow_display,
    OnlineWindow_M_diagnosis, 
    SEPARATOR,
    OnlineWindow_yt,
  }
}


//=============================================================================
//  Online-Windows
//=============================================================================

MENU OnlineWindow_S_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_S_diagnosis_status
  }
}

MENU OnlineWindow_M_diagnosis
{
  LABEL	[menu_dialog_diagnosis];
  ITEMS {
    OnlineWindow_diagnosis_device,
    Page_M_diagnosis_status
  }
}

//-------------------------------------

MENU OnlineWindow_diagnosis_device
{
  LABEL	[menu_ident_device];
  ITEMS {
    tag						(READ_ONLY),
    manufacturer_id			(READ_ONLY),
    device_id				(READ_ONLY),
    device_type				(READ_ONLY),
    physical_signaling_code	(READ_ONLY),
    final_assembly_number	(READ_ONLY),
    date					(READ_ONLY),
    software_revision		(READ_ONLY),
    hardware_revision		(READ_ONLY),
    transmitter_revision	(READ_ONLY),
    universal_revision		(READ_ONLY),
    request_preambles		(READ_ONLY),
    write_protect			(READ_ONLY)
  }
}

//-------------------------------------

MENU OnlineWindow_display
{
        LABEL   [menu_dialog_display];
        ITEMS
        {
			BarVal_pv_display,
			primary_measurement_digital_value		(READ_ONLY),
			primary_measurement_percent_range		(READ_ONLY),
			ma_analog_output_value					(READ_ONLY),
			sensor1_measurement_digital_value		(READ_ONLY),
			sensor2_measurement_digital_value		(READ_ONLY),
			electronics_temperature_digital_value	(READ_ONLY)
		}
}

MENU BarVal_pv_display
{
	LABEL		[PV_VALUE];
	ITEMS
	{
		primary_measurement_digital_value,
		primary_measurement_lower_range_value (READ_ONLY),
		primary_measurement_upper_range_value (READ_ONLY)
	}
}

//-------------------------------------

MENU Page_S_diagnosis_status
{
  LABEL	"Errors && warnings" "|de|Fehler && Warnungen";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
//    xmtr_specific_status_1 (READ_ONLY),
    xmtr_specific_status_2 (READ_ONLY),
    xmtr_specific_status_3 (READ_ONLY),
    xmtr_specific_status_4 (READ_ONLY),
    xmtr_specific_status_5 (READ_ONLY),
    configuration_flag_reset,
	master_reset
  }
}

MENU Page_M_diagnosis_status
{
  LABEL	"Errors && warnings" "|de|Fehler && Warnungen";
  ITEMS {
    xmtr_specific_status_0 (READ_ONLY),
//    xmtr_specific_status_1 (READ_ONLY),
    xmtr_specific_status_2 (READ_ONLY),
    xmtr_specific_status_3 (READ_ONLY),
    xmtr_specific_status_4 (READ_ONLY),
    xmtr_specific_status_5 (READ_ONLY),
  }
}

//=============================================================================
//  OnlineDialog
//=============================================================================

MENU OnlineDialog_sensor_ueberwachung
{
  LABEL	[menu_sensor_ueberwachung];
  ITEMS 
  {
	sensor_monitor
  }
}

MENU OnlineDialog_hart_comm2
{
  LABEL	[menu_HART_Comm];
  ITEMS {
	Page_request_response_preambles2
  }
}

MENU Page_request_response_preambles2
{
  LABEL	[menu_request_response_preambles];
  ITEMS {
    response_preambles,
    request_preambles,
  }
}
 
MENU OnlineDialog_Device_NodeAddress
{
        LABEL           [menu_Device_NodeAddress];
        ITEMS
        {
           Page_Device_NodeAddress
        }
}

MENU Page_Device_NodeAddress
{
        LABEL           [menu_Device_NodeAddress];
        ITEMS
        {
           polling_address
        }
}

//-------------------------------------

/* HART Communication Settings	 */

VARIABLE polling_address
{
  HELP [polling_address_help];
/*
  APPHELP "NOTE- This variable can affect the Data Link Layer."
	  " NOTE- This variable can affect the Multidrop Mode in the Field"
	  " Device. Value > 0 enables the Multidrop Mode for"
	  " Analog Output 1)."
	  " NOTE- This variable can affect the Analog Output Fixed Mode in the"
	  " Field Device." Value > 0 enables the Analog Output Fixed Mode for
	  " Analog Output 1)."
	  " HART_VAR:POLL ADDR";
*/
  LABEL [polling_address];
  HANDLING WRITE;
  CLASS HART;
  TYPE UNSIGNED_INTEGER
  {
	  DEFAULT_VALUE 0;
	  MIN_VALUE 0;
	  MAX_VALUE 15;
  }
}

COMMAND write_polling_address
{
	NUMBER 6;

	OPERATION WRITE;

	TRANSACTION
		{
			REQUEST
				{
					polling_address
				}

			REPLY
				{
					response_code, device_status, polling_address
				}
		}

	RESPONSE_CODES
		{
			0,	SUCCESS,			[no_command_specific_errors];
			2,	DATA_ENTRY_ERROR,	[invalid_selection];
			5,	MISC_ERROR,			[too_few_data_bytes_recieved];
			6,	MISC_ERROR,			[xmtr_specific_command_error];
			7,	MODE_ERROR,			[in_write_protect_mode];
			16,	MODE_ERROR,			[access_restricted];
		}
}

/*******************************************************************************/
/*****    Table: Instandhalter *************************************************/
/*******************************************************************************/

MENU Table_Main_Maintenance 
{
    LABEL         DEVICE_TITLE ;
    ITEMS
    {
			Tab_ident											// MENU
			Tab_m_input,										// MENU
			Tab_m_output										// MENU
    }
}

MENU Tab_m_input
{
    LABEL        [menu_input];
    ITEMS
    {
		sensor_typ 					(READ_ONLY),
		n_sensor					(READ_ONLY),
		messart						(READ_ONLY),
		wire_no						(READ_ONLY),
		sensor_monitor				(READ_ONLY),
		sensor_serial_number		(READ_ONLY),
		Tab_configure_freestyle		(READ_ONLY),
		Tab_m_input_measrange		(READ_ONLY)
    }
}

MENU Tab_m_input_measrange
{
    LABEL        [menu_input_measrange];
    ITEMS
    {
		digital_units								(READ_ONLY),
		primary_measurement_lower_sensor_limit,
		primary_measurement_upper_sensor_limit,
		primary_measurement_damping_value			(READ_ONLY)
    }
}

MENU Tab_m_output
{
    LABEL        [menu_output];
    ITEMS
    {
		alter_selector						(READ_ONLY),
		alter_value							(READ_ONLY),
		Tab_m_input_measwindow,
		Tab_m_analog_output
    }
}

MENU Tab_m_input_measwindow
{
    LABEL        [menu_input_measwindow];
    ITEMS
    {
		primary_measurement_lower_range_value							(READ_ONLY),
		primary_measurement_upper_range_value							(READ_ONLY),
		primary_measurement_minimum_span
    }
}

MENU Tab_m_analog_output
{
    LABEL        [menu_analog_output];
    ITEMS
    {
		out_select							(READ_ONLY),
		out_under							(READ_ONLY),
		out_over							(READ_ONLY)
    }
}

/*******************************************************************************/
/*****    Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Table_Main_Specialist
{
    LABEL         DEVICE_TITLE ;
    ITEMS
    {
			Tab_ident											// MENU
			Tab_s_input,											// MENU
			Tab_s_output										// MENU
    }
}


/*******************************************************************************/

MENU Tab_ident
{
	LABEL	[menu_ident];
	ITEMS
	{
		Tab_ident_opunit_universal,
		Tab_ident_device
	}
}

MENU Tab_ident_opunit_universal
{
	LABEL	[menu_ident_opunit];
	ITEMS
	{
		tag,
		descriptor,
		message
	}
}

MENU Tab_ident_device
{
	LABEL	[menu_ident_device];
	ITEMS
	{
		manufacturer_id,
		private_label_distributor,
		device_type,
		device_id,
		universal_revision,
		transmitter_revision,
		software_revision,
		hardware_revision,
		DD_Revision,
		physical_signaling_code,
		final_assembly_number,
		write_protect,
		request_preambles,
		date
	}
}

MENU Tab_s_input
{
    LABEL        [menu_input];
    ITEMS
    {
		sensor_typ 					(READ_ONLY),
		n_sensor					(READ_ONLY),
		messart						(READ_ONLY),
		wire_no						(READ_ONLY),
		sensor_monitor				(READ_ONLY),
		sensor_serial_number		(READ_ONLY),
		Tab_configure_freestyle		(READ_ONLY),
		Tab_s_input_measrange		(READ_ONLY)
    }
}

MENU Tab_s_input_measrange
{
    LABEL        [menu_input_measrange];
    ITEMS
    {
		digital_units,
		primary_measurement_lower_sensor_limit,
		primary_measurement_upper_sensor_limit,
		primary_measurement_damping_value
    }
}

MENU Tab_s_output
{
    LABEL        [menu_output];
    ITEMS
    {
		alter_selector,
		alter_value,
		Tab_s_input_measwindow,
		Tab_s_analog_output
    }
}

MENU Tab_s_input_measwindow
{
    LABEL        [menu_input_measwindow];
    ITEMS
    {
		primary_measurement_lower_range_value,
		primary_measurement_upper_range_value,
		primary_measurement_minimum_span
    }
}

MENU Tab_s_analog_output
{
    LABEL        [menu_analog_output];
    ITEMS
    {
		out_select,
		out_under,
		out_over
    }
}

MENU Tab_configure_freestyle
{
    LABEL [menu_configure_freestyle];
    ITEMS
    {
        sensor_name                         /* VARIABLE     */
    }
}

MENU OnlineDialog_hart_output
{
    LABEL [label_hart_output];
	ITEMS
	{
		polling_address,							// Variable
		response_preambles,							// Variable
		usr_threshold1, 							// Variable
		usr_threshold2								// Variable
	}
}

MENU OnlineDialog_measuring_elements
{
    /*
     *  Sensoren...
     */
    LABEL "Sensor";
    ITEMS
    {
        configure_sensor,                             /* METHOD       */
//        configure_freestyle,                          /* MENU         */
        sensor_name,									/* VARIABLE     */
        edit_curve,										/* METHOD       */
        PV.SENSOR_SERIAL_NUMBER,                      /* VARIABLE     */
        menu_sensor_info,                             /* MENU         */
        PV.LOWER_SENSOR_LIMIT (DISPLAY_VALUE),
        PV.UPPER_SENSOR_LIMIT (DISPLAY_VALUE),
        PV.MINIMUM_SPAN       (DISPLAY_VALUE),
        wire_trim                                     /* METHOD       */
    }
}

MENU configure_freestyle
{
    LABEL TXT_FREESTYLE_CONFIG;
    ITEMS
    {
        sensor_name,                         // VARIABLE    
        edit_curve                           // METHOD       
    }
}

/*
MENU menu_sensor_info
{
    //  Sensorinformationen...

    ITEMS
    {
        PV.LOWER_SENSOR_LIMIT (DISPLAY_VALUE),
        PV.UPPER_SENSOR_LIMIT (DISPLAY_VALUE),
        PV.MINIMUM_SPAN       (DISPLAY_VALUE)
    }
}
*/
MENU OnlineDialog_signal_conditioning
{
    //  Signalverarbeitung...
    LABEL [label_signal_conditioning];
    ITEMS
    {
		primary_measurement_lower_sensor_limit
		primary_measurement_upper_sensor_limit
		primary_measurement.PERCENT_RANGE (DISPLAY_VALUE, READ_ONLY),
		primary_measurement.LOWER_RANGE_VALUE (DISPLAY_VALUE),
		primary_measurement.UPPER_RANGE_VALUE (DISPLAY_VALUE),
//		select_unit,										// METHOD fbi
		primary_measurement.DAMPING_VALUE (DISPLAY_VALUE)
    }
}

MENU OnlineDialog_analog_output
{
    /*
     *  Analogausgang...
     */
    LABEL [label_analog_output];
    ITEMS
    {
        PV.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),       /* VARIABLE */
        configure_output                                  /* METHOD   */
        loop_test,                                        /* METHOD   */
        dac_trim,                                         /* METHOD   */
        scaled_dac_trim                                   /* METHOD   */
    }
}

MENU OnlineDialog_device_info
{
    /*
     *  allgemeine Informationen ueber das angeschlossene Geraet und
     *  die dazugehoerende Messstelle...
     */
    LABEL [label_device_info];
    ITEMS
    {
        tag(DISPLAY_VALUE),                               /* VARIABLE */
        descriptor(DISPLAY_VALUE),                        /* VARIABLE */
        message(DISPLAY_VALUE),                           /* VARIABLE */
        date(DISPLAY_VALUE),                              /* VARIABLE */
        final_assembly_number(DISPLAY_VALUE),             /* VARIABLE */

        private_label_distributor (DISPLAY_VALUE, READ_ONLY),
        device_type (DISPLAY_VALUE, READ_ONLY),
        write_protect (DISPLAY_VALUE, READ_ONLY),
//        _version,                                         /* VARIABLE */
//        device_revisions                                  /* MENUE    */
		universal_revision (DISPLAY_VALUE),
		transmitter_revision (DISPLAY_VALUE),
		software_revision (DISPLAY_VALUE)
    }
}
/*
MENU device_revisions
{
	LABEL [revision_numbers];
	ITEMS
	{
		universal_revision (DISPLAY_VALUE),
		transmitter_revision (DISPLAY_VALUE),
		software_revision (DISPLAY_VALUE)
	}
}
*/

/* **************************************************************************** */

// MANUFACTURER HARTMANN_BRAUN, DEVICE_TYPE _TH02, DEVICE_REVISION 1, DD_REVISION 1

/* **************************************************************************** */

/*
 *  Differenz-Messung gewaehlt...
 */

#define DIFF    ( (messart & 0x18) == 0x08 )


/*
 *  Mittelwert-Messung (mit/ohne Redundanz) gewaehlt...
 */

#define MID     ( (messart & 0x18) == 0x18 )



/*
 *  (un-)gueltige Vergleichsstelle
 */

#define JTMP    1


/*
 *  echte 2-Kanal-Messung (nicht mit Vergleichsstelle) aktiv ???
 */

#define VALID_MIDIFF       IF( DIFF || MID )   \
                           {                   \
                               TRUE;           \
                           }                   \
                           ELSE                \
                           {                   \
                               FALSE;          \
                           }


#define VALID_NON_MIDIFF   !VALID_MIDIFF


/*
 *  Vergleichsstellentemperatur gueltig ???
 */

#define VALID_JUNCTMP      IF( JTMP )          \
                           {                   \
                               TRUE;           \
                           }                   \
                           ELSE                \
                           {                   \
                               FALSE;          \
                           }

#define VALID_NON_JUNCTMP  !VALID_JUNCTMP


/*
 *  Die Reihenfolge der folgenden #include -Dateien muss eingehalten werden,
 *  damit Probleme beim Uebersetzen vermieden werden...
 */


#include "THxxx.ddl"

#include "TH02im.ddl"
#include "TH02co.ddl"
#include "TH02re.ddl"
#include "TH02mt.ddl"
#include "TH02fs.ddl"
#include "TH02tp.ddl"
#include "TH02me.ddl"


/*
 *  Dynamische (vom Messumformer selbstaetig aenderbare) Variablen
 *
 *  dahinter verbergen sich die wichtigsten Messwerte, naemlich
 *
 *  - Messwert (PV)
 *  - int./ext. Vergl.-Temperatur
 *  - Messwerte der einzelnen Sensoren (in elektr. Einheit)
 */

ARRAY OF COLLECTION dynamic_variables
{
    LABEL TXT_DYNAMIC_VARIABLES;
    HELP [dynamic_variable_help];

    ELEMENTS
    {
        PRIMARY,    transmitter_variables[0],  [pv],  TXT_PRIMARY_MEASURE;
        SECONDARY,  transmitter_variables[1],  [sv],  TXT_SECONDARY_MEASURE;
        TERTIARY,   transmitter_variables[2],  [tv],  [sensor_a_temperature_measurement_value];
        FOURTH,     transmitter_variables[3],  [qv],  [sensor_b_temperature_measurement_value];
    }
}



/*
 *  Zusammenfassung der Feldgeraete-Variablen...
 */

ARRAY OF COLLECTION transmitter_variables
{
    LABEL [transmitter_variable];
    HELP  [transmitter_variable_help];

    ELEMENTS
    {
        0, primary_measurement,            TXT_PRIMARY_MEASURE,   HLP_PRIMARY_MEASURE;
        1, reference_junction_temperature, TXT_SECONDARY_MEASURE, HLP_SECONDARY_MEASURE;
        2, sensor1_measurement,            [sensor_a_temperature_measurement_value];
        3, sensor2_measurement,            [sensor_b_temperature_measurement_value];
    }
}



/* ************************************************************************** */
/*                                                                            */
/*                       PV - H A U P T V A R I A B L E                       */
/*                                                                            */
/* ************************************************************************** */

COLLECTION OF VARIABLE primary_measurement
{
    HELP    IF MID
            {
                HLP_PM_COLLECT_MID;
            }
            ELSE
            {
                IF DIFF
                {
                    HLP_PM_COLLECT_DIFF;
                }
                ELSE
                {
                    HLP_PM_COLLECT_SINGLE;
                }
            }

    LABEL   IF MID
            {
                TXT_PM_COLLECT_DIFF;
            }
            ELSE
            {
                IF DIFF
                {
                    [differential_measurement];
                }
                ELSE
                {
                    TXT_PM_COLLECT_SINGLE;
                }
            }

    MEMBERS
    {

        DIGITAL_UNITS,         digital_units,                           [units],                 [digital_units_help];
        DIGITAL_VALUE,         primary_measurement_digital_value,       TXT_PV_VALUE,            [digital_value_help];
        PERCENT_RANGE,         primary_measurement_percent_range,       TXT_PV_PERCENT_2,        [percent_of_range_help];

        TRANSFER_FUNCTION,     analog_output_transfer_function,         [transfer_function],     [transfer_function_help];

        RANGE_UNITS,           digital_units,                           [range_units],           [range_units_help];
        UPPER_RANGE_VALUE,     primary_measurement_upper_range_value,   [urv],                   [upper_range_value_help];
        LOWER_RANGE_VALUE,     primary_measurement_lower_range_value,   [lrv],                   [lower_range_value_help];
        DAMPING_VALUE,         primary_measurement_damping_value,       [damping_value],         [seconds_damping_value_help];

        SENSOR_SERIAL_NUMBER,  sensor_serial_number,                    [sensor_serial_number],  [sensor_serial_number_help];
        SENSOR_UNITS,          digital_units,                           [sensor_unit],           [sensor_minspan_unit_help];
        UPPER_SENSOR_LIMIT,    primary_measurement_upper_sensor_limit,  [usl],                   [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,    primary_measurement_lower_sensor_limit,  [lsl],                   [lower_sensor_limit_help];
        MINIMUM_SPAN,          primary_measurement_minimum_span,        [minimum_span],          [minimum_span_help];

        ANALOG_VALUE,          ma_analog_output_value,                  [analog_output_value],   [analog_value_help];
        ALARM_CODE,            ma_analog_output_alarm_select,           [alarm_select],          [alarm_code_help];

    }
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE digital_units:  Common - Tables II  UNIT_CODES                   */
/*                                                                            */
/*                           Diese Variable ist fuer die Einheiten gedacht,   */
/*                           die mit den Messwerten, Messbereichen, Sensor-   */
/*                           grenzen, etc. gelesen und geschrieben werden.    */
/*                                                                            */
/*                           Um Refresh-Probleme zu vermeiden, wird die       */
/*                           Variable einfach als dynamisch vereinbart.       */
/* -------------------------------------------------------------------------- */

VARIABLE digital_units
{
    LABEL [units];
    HELP  [digital_units_help];

    CLASS INPUT;

    TYPE ENUMERATED
    {
        IF( sensor_typ < 2 )                       /* linear 1:1             */
        {
            IF( messart & 0x40 )
            {
                UNITS_CODE (36)                     /* millivolts             */
            }
            ELSE
            {
                UNITS_CODE (37)                     /* ohms                   */
            }
        }
        ELSE
        {
            IF( sensor_typ == 2 )                   /* Freistil               */
            {
                /* alles zulaessig (im Rahmen) */
                UNITS_CODE (32),                    /* degrees Celsius        */
                UNITS_CODE (33),                    /* degrees Fahrenheit     */
                UNITS_CODE (34),                    /* degrees Rankine        */
                UNITS_CODE (35),                    /* Kelvin                 */
                UNITS_CODE (253)                    /* -/-                    */
            }
            ELSE
            {
                /* RTD oder TC */
                UNITS_CODE (32),                /* degrees Celsius        */
                UNITS_CODE (33),                /* degrees Fahrenheit     */
                UNITS_CODE (34),                /* degrees Rankine        */
                UNITS_CODE (35)                 /* Kelvin                 */
            }
        }
    }

    HANDLING READ & WRITE;
}
/*
	PRE_EDIT_ACTIONS
	{
		digital_units_PreEdit
	}

	POST_EDIT_ACTIONS
	{
		digital_units_PostEdit
	}
}

VARIABLE digital_units_loc
{
    LABEL		[range_units];
    CLASS		LOCAL;
    TYPE		INTEGER(1);
}

METHOD digital_units_PreEdit
{
	LABEL [primary_range_units_PreEdit];

	DEFINITION
	{
		digital_units_loc = digital_units;
	}
}

METHOD digital_units_PostEdit
{
	LABEL [primary_range_units_PostEdit];

	DEFINITION
	{
      if (C200_sensor_type_erw_function == 0)
	  {
	    if ((C200_sensor_type_rm_sensor_type <= 13) && ((primary_range_units == 36) || (primary_range_units == 37)))
		  primary_range_units = digital_units_loc;

		if (C200_sensor_type_rm_sensor_type == 14)
		  primary_range_units = 37;

		if (C200_sensor_type_rm_sensor_type == 15)
		  primary_range_units = 36;
	  }
	}
}

*/

/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_digital_value:  PV - Messwert; bei zwei-     */
/*                                               kanaliger Messung nach der   */
/*                                               Verknuepfung der Kanaele.    */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_digital_value
{
    HELP    HLP_PV_VALUE;
    LABEL   IF MID
            {
                TXT_PV_MID_VALUE;
            }
            ELSE
            {
                IF DIFF
                {
                    TXT_PV_DIFF_VALUE;
                }
                ELSE
                {
                    TXT_PV_VALUE;
                }
            }

    CLASS INPUT & DYNAMIC;

    TYPE  FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }

    HANDLING READ;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_percent_range:  WMAT - Prozentwert der durch */
/*                                               den parametrierten Mess-     */
/*                                               bereich gegebenen Ausgangs-  */
/*                                               spanne.                      */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_percent_range
{
    HELP    HLP_PERCENT_RANGE;
/*    LABEL   IF MID
            {
                TXT_PV_MID_VALUE;
            }
            ELSE
            {
                IF DIFF
                {
                    TXT_PV_DIFF_VALUE;
                }
                ELSE
                {
                    TXT_PV_VALUE;
                }
            }
*/
    LABEL   TXT_PV_PERCENT_2;
//    LABEL   [TXT_PV_PERCENT];
    CLASS INPUT & DYNAMIC;

    TYPE FLOAT
    {
        EDIT_FORMAT    "2.2f";
        DISPLAY_FORMAT  ".2f";
    }

    CONSTANT_UNIT "%";

    HANDLING READ;
}

VARIABLE limit_min
{
        LABEL "limit_0";
        CLASS LOCAL;
        TYPE  INTEGER (2)
        {
                DEFAULT_VALUE 0;
        }
}
VARIABLE limit_max
{
        LABEL "limit_0";
        CLASS LOCAL;
        TYPE  INTEGER (2)
        {
                DEFAULT_VALUE 100;
        }
}


/* -------------------------------------------------------------------------- */
/*  VARIABLE analog_output_transfer_function:  Gibt Hinweise auf die          */
/*                                             Messwertverarbeitung im        */
/*                                             Feldgeraet.                    */
/*                                                                            */
/*                LINEAR wird bei eingebauten Kennlinien oder ausgeschalteter */
/*                Linearisierung angezeigt. Bei Freistilkennlinien wird dann  */
/*                SPECIAL angezeigt.                                          */
/* -------------------------------------------------------------------------- */

VARIABLE analog_output_transfer_function
{
    LABEL [transfer_function];
    HELP  [transfer_function_help];

    TYPE ENUMERATED
    {
        TRANSFER_FUNCTION_CODE   (0)     /* Linear                 */
        TRANSFER_FUNCTION_CODE (253)     /* spezial, Freistilkurve */
    }

    CLASS INPUT;
    HANDLING READ;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_upper_range_value:                           */
/*                                                                            */
/*                Prozesssignal, welches dem 20mA-Ausgangssignal entspricht.  */
/*                Eine fallende Kennlinie erhaelt man, wenn gilt:             */
/*                                                                            */
/*                primary_measurement_lower_range_value >                     */
/*                                     primary_measurement_upper_range_value  */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_upper_range_value
{
    HELP    HLP_UPPER_RANGE_VALUE;
    LABEL   [urv];

    CLASS INPUT;

    TYPE FLOAT
    {
        DISPLAY_FORMAT  ".2f";
        EDIT_FORMAT    "6.2f";
    }

    HANDLING READ & WRITE;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_upper_range_value:                           */
/*                                                                            */
/*                Prozesssignal, welches dem 4mA-Ausgangssignal entspricht.   */
/*                Eine fallende Kennlinie erhaelt man, wenn gilt:             */
/*                                                                            */
/*                primary_measurement_lower_range_value >                     */
/*                                     primary_measurement_upper_range_value  */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_lower_range_value
{
    HELP    HLP_LOWER_RANGE_VALUE;
    LABEL   [lrv];

    CLASS INPUT;

    TYPE FLOAT
    {
        DISPLAY_FORMAT  ".2f";
        EDIT_FORMAT    "6.2f";
    }

    HANDLING READ & WRITE;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_damping_value:                               */
/*                                                                            */
/*                Zeitkonstante des PT1-Daempfungsfilters im Feldgeraet.      */
/*                                                                            */
/*                Die Zeitkonstante 0.0s fuehrt zum Abschalten des Filters    */
/*                und der zusaetzlichen 50Hz-Unterdrueckung.                  */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_damping_value
{
    HELP    HLP_DAMPING_VALUE;
    LABEL   [damping_value];

    CLASS INPUT;

    TYPE FLOAT
    {
        DISPLAY_FORMAT  ".1f";
        EDIT_FORMAT    "4.1f";

        MIN_VALUE1     0.0;                        /* Daempfung ausgeschaltet */
        MAX_VALUE1   100.0;

    }

    CONSTANT_UNIT  TXT_UNIT_SEK;

    HANDLING READ & WRITE;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE sensor_serial_number:  Sensor-Seriennummer; ohne Einfluss auf    */
/*                                  die Messwert-Verarbeitung.                */
/* -------------------------------------------------------------------------- */

VARIABLE sensor_serial_number
{
    HELP  [sensor_serial_number_help];
    LABEL [sensor_serial_number];

    CLASS DEVICE;

    TYPE UNSIGNED_INTEGER (3)
    {
		DEFAULT_VALUE 0;
		MIN_VALUE          0;
		MAX_VALUE   16777215;
		DISPLAY_FORMAT  "8u";
		EDIT_FORMAT     "8u";
    }

    HANDLING READ & WRITE;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_upper_sensor_limit:                          */
/*                                                                            */
/*                Obere Einstellgrenze fuer den Messbereich. Bei 2-kanaligen  */
/*                Messungen ist das nicht der obere Sensorbereich, sondern    */
/*                die nach der Verknuepfung der Kanaele moegliche Grenze.     */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_upper_sensor_limit
{
    HELP    HLP_UPPER_SENSOR_LIMIT;
    LABEL   [usl];

    CLASS CORRECTION;

    TYPE FLOAT
    {
        DISPLAY_FORMAT  ".2f";
        EDIT_FORMAT    "6.2f";
    }

    HANDLING READ;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_lower_sensor_limit:                          */
/*                                                                            */
/*                Untere Einstellgrenze fuer den Messbereich. Bei 2-kanaligen */
/*                Messungen ist das nicht der untere Sensorbereich, sondern   */
/*                die nach der Verknuepfung der Kanaele moegliche Grenze.     */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_lower_sensor_limit
{
    HELP    HLP_LOWER_SENSOR_LIMIT;
    LABEL   [lsl];

    CLASS CORRECTION;

    TYPE FLOAT
    {
        DISPLAY_FORMAT  ".2f";
        EDIT_FORMAT    "6.2f";
    }

    HANDLING READ;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE primary_measurement_minimum_span:                                */
/*                                                                            */
/*                Minimale Spanne fuer den Messbereich.                       */
/* -------------------------------------------------------------------------- */

VARIABLE primary_measurement_minimum_span
{
    HELP    HLP_MINIMUM_SPAN;
    LABEL   [minimum_span];

    CLASS CORRECTION;

    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }

    HANDLING READ;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE ma_analog_output_value:                                          */
/*                                                                            */
/*                Groesse des Signals am Analogausgang. Hier immer ein        */
/*                Stromausgang.                                               */
/* -------------------------------------------------------------------------- */

VARIABLE ma_analog_output_value
{
    LABEL [analog_output_value];
    HELP  [analog_output_help];

    CLASS ANALOG_OUTPUT & DYNAMIC;

    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }

    CONSTANT_UNIT TXT_UNIT_MA;

    HANDLING READ & WRITE;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE ma_analog_output_alarm_select:  Fehlersignalisierung im          */
/*                                           Stoerungsfall.                   */
/* -------------------------------------------------------------------------- */

VARIABLE ma_analog_output_alarm_select
{
    LABEL TXT_AO_ALARM_CODE;
    HELP  [alarm_code_help];

    CLASS ANALOG_OUTPUT;

    TYPE ENUMERATED
    {
        {   0, [high]              },   /* uebersteuern                       */
        {   1, [low]               },   /* untersteuern                       */
        { 251, TXT_NO_SUPPLY       },   /* Wert weiterreichen                 */
        { 253, TXT_SPECIAL         }    /* halte letzten Wert oder Ersatzwert */
    }

    HANDLING READ;
}



/* ************************************************************************** */
/*                                                                            */
/*                       SV - Vergleichsstellentemperatur                     */
/*                                                                            */
/* ************************************************************************** */

COLLECTION OF VARIABLE reference_junction_temperature
{
    HELP  [electronics_temperature_help];
    LABEL [electronics_temperature];

    MEMBERS
    {
        /* NAME,        Variable                           ,Kurzbeschreibung,  Hilfstext */

        DIGITAL_UNITS,  electronics_temperature_digital_units, [units],        [digital_units_help];
        DIGITAL_VALUE,  electronics_temperature_digital_value, [blank],        [digital_value_help];
    }
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE electronics_temperature_digital_units:                           */
/*                                                                            */
/*                                  Einheit der Vergleichsstellentemperatur.  */
/* -------------------------------------------------------------------------- */

VARIABLE electronics_temperature_digital_units
{
    HELP  HLP_REFER_JUNC_UNIT;
    LABEL [cjc_temp_unit];

    CLASS INPUT & DYNAMIC;

    TYPE ENUMERATED
    {
        UNITS_CODE (32),              /* degrees Celsius */
        { 250, [not_used] }           /* not used        */
    }

    HANDLING READ;
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE electronics_temperature_digital_value:                           */
/*                                                                            */
/*                Groesse der Vergleichsstellentemperatur. Dieser Wert fuer   */
/*                interne und fuer eine externe Vergleichsstelle.             */
/* -------------------------------------------------------------------------- */

VARIABLE electronics_temperature_digital_value
{
    HELP  HLP_REFER_JUNC_VALUE;
    LABEL [cjc_temp_value]; 

    CLASS INPUT & DYNAMIC;

    TYPE FLOAT
    {
        MIN_VALUE -40.0;
        MAX_VALUE  85.0;

        DISPLAY_FORMAT  ".2f";      /* 2 Nachkommastellen,keine Mindestbreite */
        EDIT_FORMAT    "6.2f";
    }

    VALIDITY VALID_JUNCTMP          /* die Variable ist nur gueltig, wenn     */
                                    /* eine Vergleichsstelle parametriert ist */

    HANDLING READ & WRITE;
}



/* ************************************************************************** */
/*                                                                            */
/*                           TV - E I N G A N G   1                           */
/*                                                                            */
/* ************************************************************************** */

COLLECTION OF VARIABLE sensor1_measurement
{
    HELP  HLP_SENSOR1;
    LABEL [sensor_a_temperature_measurement_value];

    MEMBERS
    {
        DIGITAL_UNITS,        sensor1_digital_units,             [units],                                  HLP_SNSR_UNITS;
        DIGITAL_VALUE,        sensor1_measurement_digital_value, [sensor_a_temperature_measurement_value], HLP_SNSR1_VALUE;
    }
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE sensor1_digital_units:  Subset of Table II, Unit Codes           */
/*                                                                            */
/*                Elektrische Einheit an Eingang 1 des Feldgeraetes.          */
/* -------------------------------------------------------------------------- */

VARIABLE sensor1_digital_units
{
    HELP  HLP_SNSR_UNITS;
    LABEL [units];

    TYPE ENUMERATED
    {
        UNITS_CODE (36),                /* millivolts */
        UNITS_CODE (37),                /* ohms */
        { 250, "Not Used" }
    }

    HANDLING READ;

    CLASS INPUT & DYNAMIC;              /* DYNAMIC ist Bugfix fuer die nicht  */
                                        /* funktionierende REFRESH-Funktion.  */
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE sensor1_digital_value:  Elektrische Messgroesse am Eingang 1.    */
/*                                   Der Wert ist bereits durch die           */
/*                                   Abgleichparameter (z.B. Leitungs-        */
/*                                   abgleich) korrigiert.                    */
/* -------------------------------------------------------------------------- */

VARIABLE sensor1_measurement_digital_value
{
    HELP  HLP_SNSR1_VALUE;
    LABEL [sensor_a_temperature_measurement_value];

    CLASS INPUT & DYNAMIC;

    TYPE    FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }

    HANDLING READ;
}



/* ************************************************************************** */
/*                                                                            */
/*                           QV - E I N G A N G   2                           */
/*                                                                            */
/* ************************************************************************** */

COLLECTION OF VARIABLE sensor2_measurement
{
    HELP  HLP_SENSOR2;
    LABEL [sensor_b_temperature_measurement_value];

    MEMBERS
    {
        DIGITAL_UNITS,  sensor2_digital_units,             [units],                                  HLP_SNSR_UNITS;
        DIGITAL_VALUE,  sensor2_measurement_digital_value, [sensor_b_temperature_measurement_value], HLP_SNSR2_VALUE;
    }
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE sensor2_digital_units:  Subset of Table II, Unit Codes           */
/*                                                                            */
/*                Elektrische Einheit an Eingang 2 des Feldgeraetes.          */
/* -------------------------------------------------------------------------- */

VARIABLE sensor2_digital_units
{
    HELP  HLP_SNSR_UNITS;
    LABEL [units];

    TYPE ENUMERATED
    {
        UNITS_CODE (36),                /* millivolts */
        UNITS_CODE (37),                /* ohms */
        { 250, "Not Used" }
    }

    VALIDITY VALID_MIDIFF               /* Variable nur bei 2-kanaliger */
                                        /* Messung gueltig.             */
    HANDLING READ;

    CLASS INPUT & DYNAMIC;              /* DYNAMIC ist Bugfix fuer die nicht  */
                                        /* funktionierende REFRESH-Funktion.  */
}



/* -------------------------------------------------------------------------- */
/*  VARIABLE sensor2_digital_value:  Elektrische Messgroesse am Eingang 2.    */
/*                                   Der Wert ist bereits durch die           */
/*                                   Abgleichparameter (z.B. Leitungs-        */
/*                                   abgleich) korrigiert.                    */
/* -------------------------------------------------------------------------- */

VARIABLE sensor2_measurement_digital_value
{
    HELP  HLP_SNSR2_VALUE;
    LABEL [sensor_b_temperature_measurement_value];

    CLASS INPUT & DYNAMIC;

    TYPE    FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }

    VALIDITY VALID_MIDIFF               /* Variable nur bei 2-kanaliger */
                                        /* Messung gueltig.             */
    HANDLING READ;
}

